#delimit ;
cap log close;
log using do\adult,replace;
*************************************************************;
*                                                           *;
*    Name     : ADULT.DO                                    *;
*    Date     : Dec 18, 1996                                *;
*    OBJECTIVE: Create data on adults                       *;
*                                                           *;
*************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

**this creates data with 4817 observations -- 4544 present and 273 absent
  adult household members (of these, 51 have info in 3.1 when in fact they
  should not)
;

use coreind;
keep hhnum pcode gender age absdumm;
keep if age>=16;

***education
;
merge hhnum pcode using sec02;
tab _merge;  
drop if _merge==2; *households with incomplete information;
drop _merge;

gen edlevel=edulevel;
recode edlevel 0/3=1
               4=2
               5=3
               6/7=4
               8/9=5
               ;

label define edlevel
1 "less than primary"
2 "primary"
3 "middle"
4 "second"
5 "higher"
;
label value edlevel edlevel;
sort hhnum pcode;

***labor force
;
merge hhnum pcode using sec031;
tab _merge; 
drop if _merge==2; *incomplete questionnaires;
*drop if _merge==1 & present==0; *222 persons who were not present in hh for 
                                 more than 15 days in last month;
*drop if _merge==3 & present==0; *51 persons who are absent hh members but
                                 have filled out section 3.1 anyway;
drop if hhnum==60103&pcode==1|hhnum==190101&pcode==2|
        hhnum==190525&pcode==3|hhnum==250119&pcode==3|hhnum==650425&pcode==3;
        *from Leka's fax; 
drop _merge;

sort hhnum pcode;

merge hhnum pcode using sec032;
tab _merge;
*drop if _merge==2; *must be absent hh members;
drop _merge;
sort hhnum pcode;

merge hhnum pcode using sec033;
tab _merge;
drop if _merge==2&absdumm~=1; *incomplete questionnaires; 
drop _merge;
sort hhnum pcode;

merge hhnum pcode using sec041;
tab _merge;
drop if _merge==2&absdumm~=1; *incomplete questionnaires;
drop _merge;
sort hhnum pcode;

merge hhnum pcode using sec051;
tab _merge;
drop _merge;
sort hhnum pcode;

merge hhnum pcode using sec061;
tab _merge;
drop if _merge==2&absdumm~=1; *incomplete questionnaires;
drop _merge;

replace anywork=. if hhnum==620418&pcode==2; *not looking accorking to 3.1
                                              but (incomplete) 3.2 - ignore;

sort hhnum pcode;

merge hhnum using corehh;
tab _merge;

keep hhnum pcode bashki intermon 
     gender age absdumm
     edlevel edulevel educlast
     working7 notwork mainwork worktime lookwork notlook 
     lookjobm anywork lookhour
     difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob othertyp otherenm
     othereny otherlng
     w1sector w1weekhr w1weeksm
     selfact1 selfact2 selfwkhr selfweek selfmont
     agritime agriwks agrihrsw;
save tempdat1, replace;


use tempdat1;


gen wapop=0;
replace wapop=1 if (gender==1 & age<=60)|(gender==2 & age<=55);*working age pop.;

gen ecstat=.;

**employed**;
replace ecstat=1 if wapop==1 & (working7==1|
                                (working7==0&notwork==1&mainwork==1)|
                                (working7==0&notwork==2&mainwork==1)|
                                (working7==0&notwork==3&mainwork==1));
replace ecstat=2 if (wapop==1 & ecstat==. & working7==0) &
                                ((w1weekhr>0&w1weekhr~=.)|
                                 (selfwkhr>0&selfwkhr~=.)|
                                 (agrihrsw>0&agrihrsw~=.));
replace ecstat=3 if wapop==1 & ecstat==. & working7==0 & notlook==10; 
  *because of lack of other information, take these as employed;
replace ecstat=4 if wapop==1 & ecstat==. & working7==0 & lookwork==1 &
        (agriwks==47|agriwks==48); *Harold decided this: 4 people - 'unemployed',
                                    but worked many weeks in agriculture;

**unemployed**;
replace ecstat=5 if wapop==1 & ecstat==. & working7==0 & lookwork==1 &
                      lookhour>0 & lookhour~=.; *ILO unemployed;
replace ecstat=6 if wapop==1 & ecstat==. & working7==0 & lookwork==1 &
        anywork==1; *unemployed, but worked part-time or in family bus. (H
                     wants to keep these as unemp);
replace ecstat=7 if wapop==1 & ecstat==. & working7==0 & lookwork==1; 

**NILF**;                    
replace ecstat=8 if wapop==1 & ecstat==. & working7==0 & lookwork==0
                    & notlook==1;*discouraged workers;
replace ecstat=9 if wapop==1 & ecstat==. & working7==0 & lookwork==0;  


**pensioners - employed**;
replace ecstat=10 if wapop==0 & (working7==1|
                                (working7==0&notwork==1&mainwork==1)|
                                (working7==0&notwork==2&mainwork==1)|
                                (working7==0&notwork==3&mainwork==1));
replace ecstat=11 if (wapop==0 & ecstat==. & working7==0) &
                                ((w1weekhr>0&w1weekhr~=.)|
                                 (selfwkhr>0&selfwkhr~=.)|
                                 (agrihrsw>0&agrihrsw~=.));
replace ecstat=12 if wapop==0 & ecstat==. & working7==0 & notlook==10; 
  *because of lack of other information, take these as employed;
replace ecstat=13 if wapop==1 & ecstat==. & working7==0 & lookwork==1 &
        (agriwks==47|agriwks==48); *'unemployed',but worked many weeks in agriculture;
                                        
**pensioners - unemployed**;
replace ecstat=14 if wapop==1 & ecstat==. & working7==0 & lookwork==1 &
                      lookhour>0 & lookhour~=.; *ILO unemployed;
replace ecstat=15 if wapop==0 & ecstat==. & working7==0 & lookwork==1 &
        anywork==1; *unemployed, but worked part-time or in family bus.;
replace ecstat=16 if wapop==0 & ecstat==. & working7==0 & lookwork==1; 

**pensioners - NILF**;
replace ecstat=17 if wapop==0 & ecstat==. & working7==0 & lookwork==0
                    & notlook==1;*discouraged workers;
replace ecstat=18 if wapop==0 & ecstat==. & working7==0 & lookwork==0;  

**note can't assign ecstat to two people;

gen lfs1a=ecstat; *non-ILO definition;
recode lfs1a 1/4=1
             5/7=2 
             8/9=3
           10/13=4
           14/16=5
           17/18=6
                 ;

gen lfs1b=ecstat; *ILO definition;
recode lfs1b   1/4=1
               5=2
             6/9=3
           10/13=4
              14=5
           15/18=6
                 ;

label define lfslab
1 "wa-emp"
2 "wa-unemp"
3 "wa-NILF"
4 "ret-emp"
5 "ret-unemp"
6 "ret-NILF"
;
label value lfs1a lfslab;
label value lfs1b lfslab;
label variable lfs1a "labor force status - non ILO";
label variable lfs1b "labor force status - ILO";

**add extra variables
;
gen workwage=0;
replace workwage=1 if w1sector~=.;
gen workself=0;
replace workself=1 if selfact1~=.;

sort hhnum pcode;
save adult, replace;

/*
use adult;

gen agecat=age;
recode agecat 16/35=1
              36/60=2
              61/max=3
              ; 

label define agecat
1  "16-35 yrs"
2  "36-60 yrs"
3  "61+ yrs"
;
label value agecat agecat;
label variable agecat "Age categories"; 
/*
table agecat lfs gender if wapop==1, row col;
table agecat lfs if wapop==1, row col;
table agecat lfs gender if wapop==0, row col;
table agecat lfs if wapop==0, row col;

tab ecstat;
*/
/*
gen durunem=lookjobm;
recode durunem min/3 = 1
                 4/6 = 2
                7/12 = 3
               13/18 = 4
               19/24 = 5
               25/36 = 6
              37/max = 7
              ;
label define durunem
1 "1-3 months"
2 "4-6 months"
3 "7-12 months"
4 "13-18 months"
5 "19-24 months"
6 "25-36 months"
7 "> 3 years"
;
label value durunem durunem;
label variable durunem "Duration of unemployment";

tab durunem gender if lfs==2, row col;
tab durunem agecat if lfs==2, row col;
*/

local emp   "((jobtype1>=1&jobtype11<=10)|jobtype1==13)";
local unemp "(jobtype1=15)";
local nilf  "(jobtype1>=11&jobtype11<=12)|jobtype1==14)"
local other "(jobtype1=16)";

gen int_m  = 96*12+intermon; *interview 'month';
gen job1_m = jobenye1*12+jobenme1; *'month' job1 ended;
gen job2_m = othereny*12+otherenm; *'month' job2 ended;

gen job_3=0; *gen job_6=0; *gen job_12o=0;
replace job_3=1  if difjobe1==1;  
replace job_6o=1 if difjobe1==1; *same job at all previous points;

replace job_3=2  if difjobe1==1 & `emp' & (int_m-job1_m<=3);  
replace job_6o=2 if difjobe1==1;

tab difjobe1 otherjob if lfs==2;
*/

/*
**look at modes of education level
;
use adult;
merge hhnum using corehh;
keep hhnum pcode settlm edlevel age gender;

gen agec=age;
recode agec 16/40=1
            41/60=2
            61/max=3
            ;

label define agec
1 "16-40 yrs"
2 "41-60 yrs"
3 ">=61  yrs"
;
label value agec agec;

sum hhnum agec;

gen id=1;
collapse (count) id, by(settlm gender agec edlevel);

replace id=-id;
sort settlm gender agec id;

by settlm gender agec: keep if _n==1;

list settlm gender agec edlevel; *these are the mode education levels;
*/


log close;
