#delimit ;
cap log close;
log using do\albcore,replace;

*************************************************************;
*                                                           *;
*    Name     : ALBCORE.DO                                  *;
*    OBJECTIVE: Create core household variables             *;
*                                                           *;
*************************************************************;
clear;
set more 1;


**get final sample of households
;
use sec00;

keep if nointerv==.;
keep hhnum interdat;

**household roster information
;
merge hhnum using sec011;
tab _merge;
drop if _merge==2; *incomplete questionnaires;

gen a=1;
egen byte hhsize2=sum(a), by(hhnum); *using all hh members;
drop a;

gen a=1 if present==.|present==1;
egen byte hhsize=sum(a), by(hhnum); *using only those present >15 days last month;
drop a;

gen a=0;
replace a=1 if absent==1;
egen byte nabsent=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if absent==0 | present==1;
egen byte npresent=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if age>0 & age<=5 & (present==.|present==1);
egen byte all0_5=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if age>=6 & age<=15 & (present==.|present==1);
egen byte all6_15=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if age>=16 & age<=35 & gender==1 & (present==.|present==1);
egen byte men16_35=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if age>=16 & age<=35 & gender==2 & (present==.|present==1);
egen byte fem16_35=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if age>=36 & age<=64 & gender==1 & (present==.|present==1);
egen byte men36_64=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if age>=36 & age<=64 & gender==2 & (present==.|present==1);
egen byte fem36_64=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if age>=65 & (present==.|present==1);
egen byte all65_=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if age<14 & (present==.|present==1);
egen byte child=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if age>=14 & (present==.|present==1);
egen byte adult=sum(a), by(hhnum);
drop a;


label var hhsize2 "Household size All";
label var hhsize  "Household size";
label var nabsent "# absent hh members"; 
label var npresent"# memb present last 15 days"; 
label var all0_   "All aged 0 to 5";
label var all6_   "All aged 6 to 15";
label var men16_  "Males aged 16 to 35";
label var fem16_  "Females aged 16 to 35";
label var men36_  "Males aged 36 to 64";
label var fem36_  "Females aged 36 to 64";
label var all65   "All aged 65 and over";
label var child   "Children";
label var adult   "Adults";


***create household level file***;
sort hhnum;
qui by hhnum: keep if _n==1;

gen genhh=gender;
gen agehh=age;

gen bashki=int(hhnum/10000);
gen a=hhnum-(bashki*10000);
gen sector=int(a/100);
gen hhold=a-sector*100;
drop a;

gen settlm=bashki>=61;

gen interday=int(interdat/100);
gen intermon=interdat-interday*100;

gen region=bashki;
recode region 1/2=1
              3/13=2
              14=3
              15/21=4
              22=5
              23=6
              24/26=7
              27/34=8
              35/37=9
              38/45=10
              46/48=11
              49=12
              50=13
              ; 

label define region
1   "Berat"
2   "Diber"
3   "Durres"
4   "Elbasan" 
5   "Fier"    
6   "Gjirokas"     
7   "Korce"  
8   "Kukes"  
9   "Lezhe"  
10  "Shkoder"
11  "Tirane" 
12  "Vlore"   
13  "Elbasan"
;
label value region region; 
label define bashki
1       "Bogove"
2       "Vendres"
3       "Arras"
4       "Fushe M"
5       "Kastrio"
6       "Luzni e"
7       "Maqella"
8       "Qender"
9       "Zall Da"
10      "Klos"
11      "Mucukull"
12      "Ostren"
13      "Shupenz"
14      "Cudhi"
15      "Paper"
16      "Gjinar"
17      "Kokovjat"
18      "Lenie"
19      "Prenjas"
20      "Qukes"
21      "Sterblev"
22      "Mbrosta"
23      "Luftinje"
24      "Cerrave"
25      "Velcan"
26      "Pirg"
27      "Bicaj"
28      "Bushtric"
29      "Kolsh"
30      "Malzi"
31      "Shishtav"
32      "Terthore"
33      "Ujemisht"
34      "Fajze"
35      "Mamurra"
36      "Sellte"
37      "Kacinar"
38      "Lac"
39      "Postrlb"
40      "Rrethin"
41      "Pult"
42      "Flerze"
43      "Fushe a"
44      "Kastrat"
45      "lballe"
46      "Kashar"
47      "Vaqar"
48      "Zall Bas"
49      "Vranish"
50      "Orenje"
61      "Laci"
62      "Elbasani"
63      "Pogradeci"
64      "Korca"
65      "Vlora"
66      "Bilishti"
67      "Shkodra"
68      "Kukesi"
;
label value bashki bashki; 

label define settlm
1 "urban"
0 "rural"
;
label value settlm settlm;

drop _merge;
sort hhnum;
merge hhnum using sec091;
drop if _merge==2;
egen medcomm=median(commutem), by(bashki sector);
replace commutem=medcomm if commutem==.; 

label var bashki   "Commune/bashki";
label var sector   "Village/neighborhood";
label var region   "Region";
label var settlm   "Type of settlement";
label var interday "Day of interview";
label var intermon "Month of interview";
label var hhold    "Houshold number";
label var genhh    "Gender of household head";
label var agehh    "Age of household head";
label var commutem "Median min to center, by(bashki sector)";

keep hhnum bashki sector region settlm commutem hhold interday 
     intermon hhsize hhsize2 nabsent npresent genhh agehh 
     all* men* fem* child adult;
sort hhnum;
save temp1, replace;

**calculate sampling weights for rural households
;
use sec081;
keep hhnum sacode saany;
keep if sacode==6;
gen same=0;
replace same=1 if hhnum[_n+1]==hhnum[_n];
keep if same==0;
drop same;

merge hhnum using temp1;
tab _merge;
drop _merge;
replace saany=0 if saany==.;
sort bashki;
rename saany socass;
label var socass "Receive social Assistance - Nedime";

merge bashki using weights;
tab _merge;
label var weight   "Sample Weights";

tab sett [w=we];
tab sett [w=we*hhsize];

** The only problem is the large value of Commune 22.  
   It was reduced to the second largest value (from 5531 to 1230).
   This causes the estimation of Hhs to dro quite a bit.  
   Because of the ancertanty of the original numbers it was decided to 
   leave the estimates as they were.
   An alternative is to calculate an alternative set of weights
   expanding the rural weights by 1.34, which is the 
   ratio of the estimates using the two weights.
;
/* gen weight2=weight;
replace weight2=round(weight2*1.34,1);
replace weight2=weight if sett==1;
lab var weight2 "Modified Sample Weights";
tab sett [w=weight2];
tab sett [w=weight2*hhsize];
*/   
   
keep hhnum bashki sector region settlm commutem hhold interday 
     intermon hhsize hhsize2 nabsent npresent genhh agehh socass
     all* men* fem*  child adult we*;

label data "corehh: Core household variables";
sort hhnum;
save corehh,replace;


/*
***create individual level file - note: this includes absent hh mem.***;

use corehh;
keep hhnum;

merge hhnum using sec011;
*keep hhnum pcode age gender absent present absmonth absreas;
tab _merge;
drop if _merge==2;

gen absdumm=absent==1&present==0; *identifies absent hh members;
label variable absdumm "dummy - hh member absent";

gen agecat=age;
recode agecat 0/5=1
              6/15=2
              16/35=3
              36/64=4
              65/max=5
              ; 

label define agecat
1  "0-5 yrs"
2  "6-15 yrs"
3  "16-35 yrs"
4  "36-64 yrs"
5  "65+ yrs"
;
label value agecat agecat;
label variable agecat "Age categories"; 

keep hhnum pcode gender age agecat moved movedm absdumm absmonth absreas;
label data "coreind: Core individual variables";
sort hhnum pcode;

save coreind,replace;
*/

log close;
