#delimit;
capture log close;
log using do/calan,replace;
****************************************************************;
*                                                              *;
*    Name    : CALAN.DO                                        *;
*    OBJECTIVE: Calculate the per capita calorie consumption   *;
*               using total food consumption                   *;
****************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

use fdquant;
sort fooditem;

merge fooditem using kcalfd;

**Drop prepared meals
;
drop if grpitem==9;

**Drop all alcohol except raki
;
drop if fooditem==1204|fooditem==1205;


**convert monthly food quantities consumed into calories using the
  conversion schedule in kclafd (used in Bulgaria and Romania).
  Note the conversion factors are in kilocalories i.e.
  number of calories per kilogram of food.
;

**calories per day per fooditem 
;
gen cali1 = fdq_tot*calcon/30;
gen cali2 = fdq_tot2*calcon/30; *calories using outlier adj. quant data;
*tab fooditem, sum(cali2);

**find calories per group item and create household level data
;
cap program drop temp1;
program define temp1;

sort hhnum;
local i = 1;
while `i' < 9 {;
                disp "i is now `i'";
                egen long cal1_`i' = sum(cali1) if grpitem==`i', by(hhnum);  
                egen long cal2_`i' = sum(cali2) if grpitem==`i', by(hhnum);  
                sort hhnum grpitem;
                qui by hhnum grpitem: drop if grpitem==`i' & _n~=1;
                local i = `i' + 1;
              };
local i = 1;
while `i' < 9 {;
                disp "i is now `i'";
                egen a = mean(cal1_`i'), by (hhnum);
                replace cal1_`i' = a;
                drop a;
                egen a = mean(cal2_`i'), by (hhnum);
                replace cal2_`i' = a;
                drop a;
                local i = `i' + 1;
               };
end;
temp1;

save tempdat3, replace;

*use tempdat3;

sort hhnum;
qui by hhnum: gen a=_n;
keep if a==1;
drop a;

egen caltot1=rsum(cal1_*);
egen caltot2=rsum(cal2_*);
drop outlier;
gen outlier=1 if caltot1~=caltot2;

cap program drop temp2;
program define temp2;

local i = 1;
while `i' < 9 {;
                disp "i is now `i'";
                gen clshr_`i'=0;
                replace clshr_`i' = cal1_`i'/caltot1 if cal1_`i'>0 & cal1_`i'~=.;  
                *replace clshr_`i' = cal2_`i'/caltot2 if cal2_`i'>0 & cal2_`i'~=.;  
                local i = `i' + 1;
              };
end;
temp2;
gen cereal_s=clshr_1; 
gen vegfru_s=clshr_2; 
gen meateg_s=clshr_3; 
gen fish_s=clshr_4; 
gen dairy_s=clshr_5; 
gen oils_s=clshr_6; 
gen sugdri_s=clshr_7; 
gen raki_s=clshr_8;

**convert to calories per capita per day
;
replace caltot1=caltot1/hhsize;
replace caltot2=caltot2/hhsize;

label variable caltot1 "Cal./person/day";
label variable caltot2 "Cal./person/day - outlier adj.";
label variable cereal_s "Cereals, share of cal"; 
label variable vegfru_s "Veg & fruit, share of cal"; 
label variable meateg_s "Meat & eggs, share of cal"; 
label variable fish_s "Fish, share of cal"; 
label variable dairy_s "Dairy, share of cal"; 
label variable oils_s "Oils, share of cal"; 
label variable sugdri_s "Cond. & drnks, share of cal"; 
label variable raki_s "Raki, share of cal"; 
label variable outlier "Household had outlier in quantity";

keep hhnum hhsize caltot1 caltot2 cereal_s vegfru_s meateg_s fish_s dairy_s oils_s
     sugdri_s raki_s outlier;
sort hhnum;
lab data "Per capita calorie consumption";
save pccal, replace;

/*
use pccal, clear;
drop outlier caltot2;
sum;
format cereal_s vegfru_s meateg_s fish_s dairy_s oils_s sugdri_s raki_s %9.2f;

/*
merge hhnum using new; *hhs that were in the new data;
drop _merge;
sort hhnum;
merge hhnum using new2; *hhs with hhsize<hhsize2;
drop _merge;
sort hhnum;
*/
list if (caltot1<1000|caltot1>6000), nodisp noobs;

*merge hhnum using sec10;
*drop fpurval rectype _merge;

*sort hhnum fooditem;
local criter1 "(caltot1>1000 & caltot1<=6000)";

list if (`criter1' & caltot1>5000 & cereal_s<0.4), nodisp noobs;
list if (`criter1' & caltot1>5000 & cereal_s>0.8), nodisp noobs;
list if (`criter1' & vegfru_s>0.2), nodisp noobs;
list if (`criter1' & meateg_s>0.2), nodisp noobs;
list if (`criter1' & fish_s>0.2), nodisp noobs;
list if (`criter1' & dairy_s>0.35), nodisp noobs;
list if (`criter1' & oils_s>0.3), nodisp noobs;
list if (`criter1' & sugdri_s>0.2), nodisp noobs;
list if (`criter1' & raki_s>0.2), nodisp noobs;

/*
list hhnum hhsize caltot1 fooditem fpurqua fdprod fdreceiv fdprice new new2
      if (`criter1' & caltot1>5000 & cereal_s<0.4), nodisp noobs;
list hhnum hhsize caltot1 fooditem fpurqua fdprod fdreceiv fdprice new new2
      if (`criter1' & caltot1>5000 & cereal_s>0.8), nodisp noobs;
list hhnum hhsize caltot1 fooditem fpurqua fdprod fdreceiv fdprice new new2
      if (`criter1' & vegfru_s>0.2), nodisp noobs;
list hhnum hhsize caltot1 fooditem fpurqua fdprod fdreceiv fdprice new new2
      if (`criter1' & meateg_s>0.2), nodisp noobs;
list hhnum hhsize caltot1 fooditem fpurqua fdprod fdreceiv fdprice new new2
      if (`criter1' & fish_s>0.2), nodisp noobs;
list hhnum hhsize caltot1 fooditem fpurqua fdprod fdreceiv fdprice new new2
      if (`criter1' & dairy_s>0.35), nodisp noobs;
list hhnum hhsize caltot1 fooditem fpurqua fdprod fdreceiv fdprice new new2
      if (`criter1' & oils_s>0.3), nodisp noobs;
list hhnum hhsize caltot1 fooditem fpurqua fdprod fdreceiv fdprice new new2
      if (`criter1' & sugdri_s>0.2), nodisp noobs;
list hhnum hhsize caltot1 fooditem fpurqua fdprod fdreceiv fdprice new new2
      if (`criter1' & raki_s>0.2), nodisp noobs;
*/
*/


log close;





