#delimit ;
cap log close;
log using do\demog,replace;
**********************************************************;
*                                                        *;
*    Name     : DEMOG.DO                                 *;
*    OBJECTIVE: Demographic and education data for       *;
*               predicted expenditure regressions        *;
**********************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

**Note: both demographic and education variables pertain to all hh members, 
        absent and present.
;  

use coreind;
merge hhnum using corehh;
keep hhnum hhsize hhsize2 pcode age gender moved movedm absdumm absreas;

**determine whether whole hh 'moved to this location since 1st election'
;
**fix to the data
;
replace moved=0 if moved==.&movedm==.;

egen movnum=sum(moved), by(hhnum);

local mcrit1 "((movnum==hhsize2)|moved==0|((movnum~=hhsize2)&(movedm>12&movedm~=.)))";
local mcrit2 "((movnum==hhsize2)|moved==0|((movnum~=hhsize2)&(movedm>24&movedm~=.)))";
local mcrit3 "((movnum==hhsize2)|moved==0|((movnum~=hhsize2)&(movedm>36&movedm~=.)))";

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if age<6;
replace b=1 if age-1<6 & age-1>=0 & `mcrit1';
replace c=1 if age-2<6 & age-2>=0 & `mcrit2';
replace d=1 if age-3<6 & age-3>=0 & `mcrit3';
egen byte ychild=sum(a), by(hhnum);
egen byte ychild95=sum(b), by(hhnum);
egen byte ychild94=sum(c), by(hhnum);
egen byte ychild93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if age<16 & age>=6 & gender==1;
replace b=1 if age-1<16 & age-1>=6 & gender==1 & `mcrit1';
replace c=1 if age-2<16 & age-2>=6 & gender==1 & `mcrit2';
replace d=1 if age-3<16 & age-3>=6 & gender==1 & `mcrit3';
egen byte ochilm=sum(a), by(hhnum);
egen byte ochilm95=sum(b), by(hhnum);
egen byte ochilm94=sum(c), by(hhnum);
egen byte ochilm93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if age<16 & age>=6 & gender==2;
replace b=1 if age-1<16 & age-1>=6 & gender==2 & `mcrit1';
replace c=1 if age-2<16 & age-2>=6 & gender==2 & `mcrit2';
replace d=1 if age-3<16 & age-3>=6 & gender==2 & `mcrit3';
egen byte ochilf=sum(a), by(hhnum);
egen byte ochilf95=sum(b), by(hhnum);
egen byte ochilf94=sum(c), by(hhnum);
egen byte ochilf93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if age>=16 & age<55 & gender==1;
replace b=1 if age-1>=16 & age-1<55 & gender==1 & `mcrit1';
replace c=1 if age-2>=16 & age-2<55 & gender==1 & `mcrit2';
replace d=1 if age-3>=16 & age-3<55 & gender==1 & `mcrit3';
egen byte adultm=sum(a), by(hhnum);
egen byte adultm95=sum(b), by(hhnum);
egen byte adultm94=sum(c), by(hhnum);
egen byte adultm93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if age>=16 & age<50 & gender==2;
replace b=1 if age-1>=16 & age-1<50 & gender==2 & `mcrit1';
replace c=1 if age-2>=16 & age-2<50 & gender==2 & `mcrit2';
replace d=1 if age-3>=16 & age-3<50 & gender==2 & `mcrit3';
egen byte adultf=sum(a), by(hhnum);
egen byte adultf95=sum(b), by(hhnum);
egen byte adultf94=sum(c), by(hhnum);
egen byte adultf93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if age>=55 & gender==1;
replace b=1 if age-1>=55 & gender==1 & `mcrit1';
replace c=1 if age-2>=55 & gender==1 & `mcrit2';
replace d=1 if age-3>=55 & gender==1 & `mcrit3';
egen byte elderm=sum(a), by(hhnum);
egen byte elderm95=sum(b), by(hhnum);
egen byte elderm94=sum(c), by(hhnum);
egen byte elderm93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if age>=50 & gender==2;
replace b=1 if age-1>=50 & gender==2 & `mcrit1';
replace c=1 if age-2>=50 & gender==2 & `mcrit2';
replace d=1 if age-3>=50 & gender==2 & `mcrit3';
egen byte elderf=sum(a), by(hhnum);
egen byte elderf95=sum(b), by(hhnum);
egen byte elderf94=sum(c), by(hhnum);
egen byte elderf93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if age>60;
replace b=1 if age-1>60 & `mcrit1';
replace c=1 if age-2>60 & `mcrit2';
replace d=1 if age-3>60 & `mcrit3';
egen byte ov60=sum(a), by(hhnum);
egen byte ov6095=sum(b), by(hhnum);
egen byte ov6094=sum(c), by(hhnum);
egen byte ov6093=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0;
replace a=1 if absdumm==1&age<16;
egen byte ab_child=sum(a), by(hhnum); 
drop a;
*keep these out of absent as wouldn't be sending remittances to hh.  Also,
 keep these out of hh composition as not necessarily inc. expenditure;

gen a=0;
replace a=1 if absdumm==1&age>=16&(absreas==1|absreas==2);
egen byte abs_work=sum(a), by(hhnum);
drop a;

gen a=0;
replace a=1 if absdumm==1&age>=16&(absreas~=1&absreas~=2);
egen byte abs_oth=sum(a), by(hhnum);
drop a;

**create household level file
;
sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum ychild* ochil* adult* elder* ov* ab*; 
sort hhnum;

save temp1h, replace;

**migration variables - calculate # of migrants in hh at different
  points in time
;
use corehh;
keep hhnum intermon;

merge hhnum using sec012;
tab _merge;
keep if _merge==3;

gen int_m   = 96*12+intermon;       *interview 'month';
gen leave_m = lastresy*12+lastresm; *'month' left household;
gen monthago = int_m - leave_m;     *# months ago person left;

*calculate age when departed household
;
gen age=999;
replace age=agedeami if reasonmi==1;
replace age=agelivmi-(monthago/12) if reasonmi~=1;
replace age=0 if age<0; *fixes 3 errors;
*note - there are 2 persons who died and agedeami is missing;

keep hhnum pcode age gendermi monthago;

**migration variables for hhcomp data
;
gen b=0; gen c=0; gen d=0;
replace b=1 if age<6   & age>=0   & monthago<=12;
replace c=1 if age<6   & age>=0   & monthago<=24&monthago>12;
replace c=1 if age-1<6 & age-1>=0 & monthago<=24&monthago<=12;
replace d=1 if age<6   & age>=0   & monthago<=36&monthago>24;
replace d=1 if age-1<6 & age-1>=0 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2<6 & age-2>=0 & monthago<=36&monthago<=24&monthago<=12;
egen byte ychild95=sum(b), by(hhnum);
egen byte ychild94=sum(c), by(hhnum);
egen byte ychild93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age<16   & age>=6   & gender==1 & monthago<=12;
replace c=1 if age<16   & age>=6   & gender==1 & monthago<=24&monthago>12;
replace c=1 if age-1<16 & age-1>=6 & gender==1 & monthago<=24&monthago<=12;
replace d=1 if age<16   & age>=6   & gender==1 & monthago<=36&monthago>24;
replace d=1 if age-1<16 & age-1>=6 & gender==1 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2<16 & age-2>=6 & gender==1 & monthago<=36&monthago<=24&monthago<=12;
egen byte ochilm95=sum(b), by(hhnum);
egen byte ochilm94=sum(c), by(hhnum);
egen byte ochilm93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age<16   & age>=6   & gender==2 & monthago<=12;
replace c=1 if age<16   & age>=6   & gender==2 & monthago<=24&monthago>12;
replace c=1 if age-1<16 & age-1>=6 & gender==2 & monthago<=24&monthago<=12;
replace d=1 if age<16   & age>=6   & gender==2 & monthago<=36&monthago>24;
replace d=1 if age-1<16 & age-1>=6 & gender==2 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2<16 & age-2>=6 & gender==2 & monthago<=36&monthago<=24&monthago<=12;
egen byte ochilf95=sum(b), by(hhnum);
egen byte ochilf94=sum(c), by(hhnum);
egen byte ochilf93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>=16   & age<55   & gender==1 & monthago<=12;
replace c=1 if age>=16   & age<55   & gender==1 & monthago<=24&monthago>12;
replace c=1 if age-1>=16 & age-1<55 & gender==1 & monthago<=24&monthago<=12;
replace d=1 if age>=16   & age<55   & gender==1 & monthago<=36&monthago>24;
replace d=1 if age-1>=16 & age-1<55 & gender==1 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>=16 & age-2<55 & gender==1 & monthago<=36&monthago<=24&monthago<=12;
egen byte adultm95=sum(b), by(hhnum);
egen byte adultm94=sum(c), by(hhnum);
egen byte adultm93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>=16   & age<55   & gender==2 & monthago<=12;
replace c=1 if age>=16   & age<55   & gender==2 & monthago<=24&monthago>12;
replace c=1 if age-1>=16 & age-1<55 & gender==2 & monthago<=24&monthago<=12;
replace d=1 if age>=16   & age<55   & gender==2 & monthago<=36&monthago>24;
replace d=1 if age-1>=16 & age-1<55 & gender==2 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>=16 & age-2<55 & gender==2 & monthago<=36&monthago<=24&monthago<=12;
egen byte adultf95=sum(b), by(hhnum);
egen byte adultf94=sum(c), by(hhnum);
egen byte adultf93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>=55   & gender==1 & monthago<=12;
replace c=1 if age>=55   & gender==1 & monthago<=24&monthago>12;
replace c=1 if age-1>=55 & gender==1 & monthago<=24&monthago<=12;
replace d=1 if age>=55   & gender==1 & monthago<=36&monthago>24;
replace d=1 if age-1>=55 & gender==1 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>=55 & gender==1 & monthago<=36&monthago<=24&monthago<=12;
egen byte elderm95=sum(b), by(hhnum);
egen byte elderm94=sum(c), by(hhnum);
egen byte elderm93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>=50   & gender==2 & monthago<=12;
replace c=1 if age>=50   & gender==2 & monthago<=24&monthago>12;
replace c=1 if age-1>=50 & gender==2 & monthago<=24&monthago<=12;
replace d=1 if age>=50   & gender==2 & monthago<=36&monthago>24;
replace d=1 if age-1>=50 & gender==2 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>=50 & gender==2 & monthago<=36&monthago<=24&monthago<=12;
egen byte elderf95=sum(b), by(hhnum);
egen byte elderf94=sum(c), by(hhnum);
egen byte elderf93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>60   & monthago<=12;
replace c=1 if age>60   & monthago<=24&monthago>12;
replace c=1 if age-1>60 & monthago<=24&monthago<=12;
replace d=1 if age>60   & monthago<=36&monthago>24;
replace d=1 if age-1>60 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>60 & monthago<=36&monthago<=24&monthago<=12;
egen byte ov6095=sum(b), by(hhnum);
egen byte ov6094=sum(c), by(hhnum);
egen byte ov6093=sum(d), by(hhnum);
drop b; drop c; drop d;

**migration variables for education data
;
gen b=0; gen c=0; gen d=0;
replace b=1 if age>=16   & age<=40   & gender==1 & monthago<=12;
replace c=1 if age>=16   & age<=40   & gender==1 & monthago<=24&monthago>12;
replace c=1 if age-1>=16 & age-1<=40 & gender==1 & monthago<=24&monthago<=12;
replace d=1 if age>=16   & age<=40   & gender==1 & monthago<=36&monthago>24;
replace d=1 if age-1>=16 & age-1<=40 & gender==1 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>=16 & age-2<=40 & gender==1 & monthago<=36&monthago<=24&monthago<=12;
egen byte yadm95=sum(b), by(hhnum);
egen byte yadm94=sum(c), by(hhnum);
egen byte yadm93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>=16   & age<=40   & gender==2 & monthago<=12;
replace c=1 if age>=16   & age<=40   & gender==2 & monthago<=24&monthago>12;
replace c=1 if age-1>=16 & age-1<=40 & gender==2 & monthago<=24&monthago<=12;
replace d=1 if age>=16   & age<=40   & gender==2 & monthago<=36&monthago>24;
replace d=1 if age-1>=16 & age-1<=40 & gender==2 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>=16 & age-2<=40 & gender==2 & monthago<=36&monthago<=24&monthago<=12;
egen byte yadf95=sum(b), by(hhnum);
egen byte yadf94=sum(c), by(hhnum);
egen byte yadf93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>40   & age<=60   & gender==1 & monthago<=12;
replace c=1 if age>40   & age<=60   & gender==1 & monthago<=24&monthago>12;
replace c=1 if age-1>40 & age-1<=60 & gender==1 & monthago<=24&monthago<=12;
replace d=1 if age>40   & age<=60   & gender==1 & monthago<=36&monthago>24;
replace d=1 if age-1>40 & age-1<=60 & gender==1 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>40 & age-2<=60 & gender==1 & monthago<=36&monthago<=24&monthago<=12;
egen byte oadm95=sum(b), by(hhnum);
egen byte oadm94=sum(c), by(hhnum);
egen byte oadm93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>40   & age<=60   & gender==2 & monthago<=12;
replace c=1 if age>40   & age<=60   & gender==2 & monthago<=24&monthago>12;
replace c=1 if age-1>40 & age-1<=60 & gender==2 & monthago<=24&monthago<=12;
replace d=1 if age>40   & age<=60   & gender==2 & monthago<=36&monthago>24;
replace d=1 if age-1>40 & age-1<=60 & gender==2 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>40 & age-2<=60 & gender==2 & monthago<=36&monthago<=24&monthago<=12;
egen byte oadf95=sum(b), by(hhnum);
egen byte oadf94=sum(c), by(hhnum);
egen byte oadf93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>60   & gender==1 & monthago<=12;
replace c=1 if age>60   & gender==1 & monthago<=24&monthago>12;
replace c=1 if age-1>60 & gender==1 & monthago<=24&monthago<=12;
replace d=1 if age>60   & gender==1 & monthago<=36&monthago>24;
replace d=1 if age-1>60 & gender==1 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>60 & gender==1 & monthago<=36&monthago<=24&monthago<=12;
egen byte eldm95=sum(b), by(hhnum);
egen byte eldm94=sum(c), by(hhnum);
egen byte eldm93=sum(d), by(hhnum);
drop b; drop c; drop d;

gen b=0; gen c=0; gen d=0;
replace b=1 if age>60   & gender==2 & monthago<=12;
replace c=1 if age>60   & gender==2 & monthago<=24&monthago>12;
replace c=1 if age-1>60 & gender==2 & monthago<=24&monthago<=12;
replace d=1 if age>60   & gender==2 & monthago<=36&monthago>24;
replace d=1 if age-1>60 & gender==2 & monthago<=36&monthago<=24&monthago>12;
replace d=1 if age-2>60 & gender==2 & monthago<=36&monthago<=24&monthago<=12;
egen byte eldf95=sum(b), by(hhnum);
egen byte eldf94=sum(c), by(hhnum);
egen byte eldf93=sum(d), by(hhnum);
drop b; drop c; drop d;

**create household level file
;
sort hhnum;
qui by hhnum: keep if _n==1;

*give temporary names to some of the variables so can merge with hh comp data
;
gen a1=ychild95;
gen a2=ychild94;
gen a3=ychild93;
gen b1=ochilm95;
gen b2=ochilm94;
gen b3=ochilm93;
gen c1=ochilf95;
gen c2=ochilf94;
gen c3=ochilf93;
gen d1=adultm95;
gen d2=adultm94;
gen d3=adultm93;
gen e1=adultf95;
gen e2=adultf94;
gen e3=adultf93;
gen f1=elderm95;
gen f2=elderm94;
gen f3=elderm93;
gen g1=elderf95;
gen g2=elderf94;
gen g3=elderf93;
gen h1=ov6095;
gen h2=ov6094;
gen h3=ov6093;

keep hhnum a* b* c* d* e* f* g* h* yad* oad*;
drop gendermi age adult* elder*; *these didn't get dropped above;
sort hhnum; 

save migdath, replace; 

**merge with household composition variables
;
use migdath;
merge hhnum using temp1h;

replace ychild95=ychild95+a1 if a1~=.;
replace ychild94=ychild94+a2 if a2~=.;
replace ychild93=ychild93+a3 if a3~=.;
replace ochilm95=ochilm95+b1 if b1~=.;
replace ochilm94=ochilm94+b2 if b2~=.;
replace ochilm93=ochilm93+b3 if b3~=.;
replace ochilf95=ochilf95+c1 if c1~=.;
replace ochilf94=ochilf94+c2 if c2~=.;
replace ochilf93=ochilf93+c3 if c3~=.;
replace adultm95=adultm95+d1 if d1~=.;
replace adultm94=adultm94+d2 if d2~=.;
replace adultm93=adultm93+d3 if d3~=.;
replace adultf95=adultf95+e1 if e1~=.;
replace adultf94=adultf94+e2 if e2~=.;
replace adultf93=adultf93+e3 if e3~=.;
replace elderm95=elderm95+f1 if f1~=.;
replace elderm94=elderm94+f2 if f2~=.;
replace elderm93=elderm93+f3 if f3~=.;
replace elderf95=elderf95+g1 if g1~=.;
replace elderf94=elderf94+g2 if g2~=.;
replace elderf93=elderf93+g3 if g3~=.;
replace ov6095=ov6095+h1 if h1~=.;
replace ov6094=ov6094+h2 if h2~=.;
replace ov6093=ov6093+h3 if h3~=.;

label var ychild   "# children aged <6 yrs";
label var ychild95 "# aged <6 yrs - 1yr ago";
label var ychild94 "# aged <6 yrs - 2yrs ago";
label var ychild93 "# aged <6 yrs - 3yrs ago";
label var ochilm   "# males aged 6-15 yrs";
label var ochilm95 "# males 6-15 yrs - 1yr ago";
label var ochilm94 "# males 6-15 yrs - 2yrs ago";
label var ochilm93 "# males 6-15 yrs - 3yrs ago";
label var ochilf   "# females aged 6-15 yrs";
label var ochilf95 "# females 6-15 yrs - 1yr ago";
label var ochilf94 "# females 6-15 yrs - 2yrs ago";
label var ochilf93 "# females 6-15 yrs - 3yrs ago";
label var adultm   "# males aged >=16 yrs";
label var adultm95 "# males 16-54 yrs - 1yr ago";
label var adultm94 "# males 16-54 yrs - 2yrs ago";
label var adultm93 "# males 16-54 yrs - 3yrs ago";
label var adultf   "# females aged >=16 yrs";
label var adultf95 "# females 16-49 yrs - 1yr ago";
label var adultf94 "# females 16-49 yrs - 2yrs ago";
label var adultf93 "# females 16-49 yrs - 3yrs ago";
label var elderm   "# males aged >=55 yrs";
label var elderm95 "# males >=55 yrs - 1yr ago";
label var elderm94 "# males >=55 yrs - 2yrs ago";
label var elderm93 "# males >=55 yrs - 3yrs ago";
label var elderf   "# females aged >=50 yrs";
label var elderf95 "# females >=50 yrs - 1yr ago";
label var elderf94 "# females >=50 yrs - 2yrs ago";
label var elderf93 "# females >=50 yrs - 3yrs ago";

label var ov60     "# persons aged >60 yrs";
label var ov6095   "# persons aged >60 yrs - 1995";
label var ov6094   "# persons aged >60 yrs - 1994";
label var ov6093   "# persons aged >60 yrs - 1993";

label var ab_child "# hh mem. absent - child";
label var abs_work "# hh mem. absent - working";
label var abs_oth  "# hh mem. absent - other";

keep hhnum ychild* ochil* adult* elder* ov* ab*;
sort hhnum;

save demog, replace; 

log close;


