#delimit ;
capture log close;
log using do\durable,replace;
*************************************************************;
*                                                           *;
*    Name    : DURABLE.DO                                   *;
*    OBJECTIVE: Flow of services from durables estimates    *;
*************************************************************;
clear;
set more 1;

use corehh;
keep hhnum bashki hhsize;

merge hhnum using sec093;
tab _merge;
drop if _merge==1; *hh 611043 does not have durable info - checked with Leka;
drop if _merge==2; *hhs 460125, 640126 - incomplete questionnaires;
keep if hdurown==1;
keep if hduritem~=16 & hduritem~=17; *drop bicycles and 'other' durables;
sort hhnum;

**imputations for missing values
;
egen a=median(hduracqy), by(hduritem);
replace hduracqy=a if hduracqy==.&hdurown==1;
drop a;

gen     b=1 if hduracqy<80;
replace b=2 if hduracqy>=80&hduracqy<=92;
replace b=3 if hduracqy>=93;

egen c=median(hdurvalu), by(hduritem b);
replace hdurvalu=c if hdurvalu==.&hdurown==1;
drop b c;

gen age=96-hduracqy;
replace age=. if age>50; *too old to provide flow of services;

egen meanage=mean(age), by(hduritem);
replace hdurvalu=hdurvalu/hdurquan if hdurquan>1&hdurquan~=.; 
*more than 1 of particular type - use average resale value;

gen flowi=hdurvalu/(meanage*2); *note: the denominator is the expected lifespan of
                                 the item -- see Hentschel&Lanjouw, p.15;
replace flowi=flowi*hdurquan if hdurquan>1; *hhs with more than one of an item;
replace flowi=flowi/12; *monthly flow estimate;

egen durflow = sum(flowi), by (hhnum);

egen a = sum(hdurvalu) if hduritem>=1&hduritem<=8, by (hhnum);
egen b = sum(hdurvalu) if hduritem>=9&hduritem<=13, by (hhnum);
egen c = sum(hdurvalu) if hduritem==14|hduritem==15, by (hhnum);

egen durhh=mean(a), by(hhnum);
egen durelec=mean(b), by(hhnum);
egen durtrans=mean(c), by(hhnum);
drop a b c;

sort hhnum;
qui by hhnum: keep if _n==1;

label var durflow  "flow of services from durables";
label var durhh    "value of hh durables - 'whitegoods'";
label var durelec  "value of hh durables - electronics";
label var durtrans "value of hh durables - transport";

keep hhnum hhsize bashki durflow durhh durelec durtrans;
sort hhnum;

merge hhnum using corehh;
keep hhnum hhsize bashki durflow durhh durelec durtrans;
mvencode dur*, mv(0) ov;
sort hhnum;

save durable, replace;

log close;

 
