#delimit ;
cap log close;
log using do\educ,replace;
*********************************************************;
*                                                       *;
*    Name     : EDUC.DO                                 *;
*    OBJECTIVE: Demographic and education data for      *;
*               predicted expenditure regressions       *;
*********************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

**Note: both demographic and education variables pertain to all hh members, 
        absent and present.
;  

use coreind;
keep if age>=16; *only adults in education variables;

merge hhnum pcode using sec02;
tab _merge;  
drop if _merge==2; *5 households with incomplete information & children;
drop _merge;
sort hhnum;

merge hhnum using corehh;
keep hhnum hhsize hhsize2 settlm pcode age gender moved movedm edulevel;

**determine whether whole hh 'moved to this location since 1st election'
;
**fix to the data
;
replace moved=0 if moved==.&movedm==.;

egen movnum=sum(moved), by(hhnum);

local mcrit1 "((movnum==hhsize2)|moved==0|((movnum~=hhsize2)&(movedm>12&movedm~=.)))";
local mcrit2 "((movnum==hhsize2)|moved==0|((movnum~=hhsize2)&(movedm>24&movedm~=.)))";
local mcrit3 "((movnum==hhsize2)|moved==0|((movnum~=hhsize2)&(movedm>36&movedm~=.)))";

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if edulevel==4 & gender==1;
replace b=1 if edulevel==4 & gender==1 & `mcrit1';
replace c=1 if edulevel==4 & gender==1 & `mcrit2';
replace d=1 if edulevel==4 & gender==1 & `mcrit3';
egen byte primm=sum(a), by(hhnum);
egen byte primm95=sum(b), by(hhnum);
egen byte primm94=sum(c), by(hhnum);
egen byte primm93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if edulevel==4 & gender==2;
replace b=1 if edulevel==4 & gender==2 & `mcrit1';
replace c=1 if edulevel==4 & gender==2 & `mcrit2';
replace d=1 if edulevel==4 & gender==2 & `mcrit3';
egen byte primf=sum(a), by(hhnum);
egen byte primf95=sum(b), by(hhnum);
egen byte primf94=sum(c), by(hhnum);
egen byte primf93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if edulevel==5 & gender==1;
replace b=1 if edulevel==5 & gender==1 & `mcrit1';
replace c=1 if edulevel==5 & gender==1 & `mcrit2';
replace d=1 if edulevel==5 & gender==1 & `mcrit3';
egen byte middlm=sum(a), by(hhnum);
egen byte middlm95=sum(b), by(hhnum);
egen byte middlm94=sum(c), by(hhnum);
egen byte middlm93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if edulevel==5 & gender==2;
replace b=1 if edulevel==5 & gender==2 & `mcrit1';
replace c=1 if edulevel==5 & gender==2 & `mcrit2';
replace d=1 if edulevel==5 & gender==2 & `mcrit3';
egen byte middlf=sum(a), by(hhnum);
egen byte middlf95=sum(b), by(hhnum);
egen byte middlf94=sum(c), by(hhnum);
egen byte middlf93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if (edulevel==6|edulevel==7) & gender==1;
replace b=1 if (edulevel==6|edulevel==7) & gender==1 & `mcrit1';
replace c=1 if (edulevel==6|edulevel==7) & gender==1 & `mcrit2';
replace d=1 if (edulevel==6|edulevel==7) & gender==1 & `mcrit3';
egen byte seconm=sum(a), by(hhnum);
egen byte seconm95=sum(b), by(hhnum);
egen byte seconm94=sum(c), by(hhnum);
egen byte seconm93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if (edulevel==6|edulevel==7) & gender==2;
replace b=1 if (edulevel==6|edulevel==7) & gender==2 & `mcrit1';
replace c=1 if (edulevel==6|edulevel==7) & gender==2 & `mcrit2';
replace d=1 if (edulevel==6|edulevel==7) & gender==2 & `mcrit3';
egen byte seconf=sum(a), by(hhnum);
egen byte seconf95=sum(b), by(hhnum);
egen byte seconf94=sum(c), by(hhnum);
egen byte seconf93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if (edulevel==8|edulevel==9) & gender==1;
replace b=1 if (edulevel==8|edulevel==9) & gender==1 & `mcrit1';
replace c=1 if (edulevel==8|edulevel==9) & gender==1 & `mcrit2';
replace d=1 if (edulevel==8|edulevel==9) & gender==1 & `mcrit3';
egen byte highm=sum(a), by(hhnum);
egen byte highm95=sum(b), by(hhnum);
egen byte highm94=sum(c), by(hhnum);
egen byte highm93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

gen a=0; gen b=0; gen c=0; gen d=0;
replace a=1 if (edulevel==8|edulevel==9) & gender==2;
replace b=1 if (edulevel==8|edulevel==9) & gender==2 & `mcrit1';
replace c=1 if (edulevel==8|edulevel==9) & gender==2 & `mcrit2';
replace d=1 if (edulevel==8|edulevel==9) & gender==2 & `mcrit3';
egen byte highf=sum(a), by(hhnum);
egen byte highf95=sum(b), by(hhnum);
egen byte highf94=sum(c), by(hhnum);
egen byte highf93=sum(d), by(hhnum);
drop a; drop b; drop c; drop d;

**create household level file
;
sort hhnum;
qui by hhnum: keep if _n==1;

**following adjusts for cases where whole household moved to present location
;
replace primm95=primm if movnum==hhsize2;
replace primm94=primm if movnum==hhsize2;
replace primm93=primm if movnum==hhsize2;
replace primf95=primf if movnum==hhsize2;
replace primf94=primf if movnum==hhsize2;
replace primf93=primf if movnum==hhsize2;
replace middlm95=middlm if movnum==hhsize2;
replace middlm94=middlm if movnum==hhsize2;
replace middlm93=middlm if movnum==hhsize2;
replace middlf95=middlf if movnum==hhsize2;
replace middlf94=middlf if movnum==hhsize2;
replace middlf93=middlf if movnum==hhsize2;
replace seconm95=seconm if movnum==hhsize2;
replace seconm94=seconm if movnum==hhsize2;
replace seconm93=seconm if movnum==hhsize2;
replace seconf95=seconf if movnum==hhsize2;
replace seconf94=seconf if movnum==hhsize2;
replace seconf93=seconf if movnum==hhsize2;
replace highm95=highm if movnum==hhsize2;
replace highm94=highm if movnum==hhsize2;
replace highm93=highm if movnum==hhsize2;
replace highf95=highf if movnum==hhsize2;
replace highf94=highf if movnum==hhsize2;
replace highf93=highf if movnum==hhsize2;

**merge with data on persons who have migrated from household
;
merge hhnum using migdath;

**adult.do calculates mode education levels for different age/gender/settlm
  groups -- use this information to add migrants to historical education
  variables.  See printout (2/24) for mode education information
; 
replace primf95=primf95+oadf95 if oadf95~=.&settlm==0;
replace primf94=primf94+oadf94 if oadf94~=.&settlm==0;
replace primf93=primf93+oadf93 if oadf93~=.&settlm==0;

egen adm95=rsum(yadm95 oadm95);
egen adm94=rsum(yadm94 oadm94);
egen adm93=rsum(yadm93 oadm93);
replace middlm95=middlm95+adm95 if adm95~=.&settlm==0;
replace middlm94=middlm94+adm94 if adm94~=.&settlm==0;
replace middlm93=middlm93+adm93 if adm93~=.&settlm==0;
replace middlf95=middlf95+yadf95 if yadf95~=.&settlm==0;
replace middlf94=middlf94+yadf94 if yadf94~=.&settlm==0;
replace middlf93=middlf93+yadf93 if yadf93~=.&settlm==0;
replace middlf95=middlf95+oadf95 if oadf95~=.&settlm==1;
replace middlf94=middlf94+oadf94 if oadf94~=.&settlm==1;
replace middlf93=middlf93+oadf93 if oadf93~=.&settlm==1;
drop adm95 adm94 adm93;

egen adm95=rsum(yadm95 oadm95 eldm95);
egen adm94=rsum(yadm94 oadm94 eldm94);
egen adm93=rsum(yadm93 oadm93 eldm93);
replace seconm95=seconm95+adm95 if adm95~=.&settlm==1;
replace seconm94=seconm94+adm94 if adm94~=.&settlm==1;
replace seconm93=seconm93+adm93 if adm93~=.&settlm==1;
replace seconf95=seconf95+yadf95 if yadf95~=.&settlm==1;
replace seconf94=seconf94+yadf94 if yadf94~=.&settlm==1;
replace seconf93=seconf93+yadf93 if yadf93~=.&settlm==1;

label var primm  "# males with primary or less";
label var primm95  "# males, prim or less - 1yr ago";
label var primm94  "# males, prim or less - 2yrs ago";
label var primm93  "# males, prim or less - 3yrs ago";
label var primf  "# females with primary or less";
label var primf95  "# females, prim or less - 1yr ago";
label var primf94  "# females, prim or less - 2yrs ago";
label var primf93  "# females, prim or less - 3yrs ago";
label var middlm "# males with middle ed.";
label var middlm95 "# males, middle ed. - 1yr ago";
label var middlm94 "# males, middle ed. - 2yrs ago";
label var middlm93 "# males, middle ed. - 3yrs ago";
label var middlf "# females with middle ed.";
label var middlf95 "# females, middle ed. - 1yr ago";
label var middlf94 "# females, middle ed. - 2yrs ago";
label var middlf93 "# females, middle ed. - 3yrs ago";
label var seconm "# males with secondary ed.";
label var seconm95 "# males, secondary ed. - 1yr ago";
label var seconm94 "# males, secondary ed. - 2yrs ago";
label var seconm93 "# males, secondary ed. - 3yrs ago";
label var seconf "# females with secondary ed.";
label var seconf95 "# females, secondary ed. - 1yr ago";
label var seconf94 "# females, secondary ed. - 2yrs ago";
label var seconf93 "# females, secondary ed. - 3yrs ago";
label var highm  "# males with higher ed.";
label var highm95  "# males, higher ed. - 1 yr ago";
label var highm94  "# males, higher ed. - 2 yrs ago";
label var highm93  "# males, higher ed. - 3 yrs ago";
label var highf  "# females with higher ed.";
label var highf95  "# females, higher ed. - 1 yr ago";
label var highf94  "# females, higher ed. - 2 yrs ago";
label var highf93  "# females, higher ed. - 3 yrs ago";

keep hhnum prim* middl* secon* high*;
sort hhnum;
save educ, replace;


log close;


