#delimit ;
cap log close;
log using do\entitle,replace;
**********************************************;
*                                            *;
*    Name     : ENTITLE.DO                   *;
*    OBJECTIVE: Calculate NE entitlement     *;
*                                            *;
**********************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

**first -- find # of 'invalids' in hh
;
use coreind;

merge hhnum pcode using sec031;
tab _merge;
drop if _merge==2;
gen inv=(notlook==2|notlook==3);
keep if inv==1;
keep hhnum pcode age inv;
sort hhnum pcode;

merge hhnum pcode using sec121;
tab _m; drop if _m==2; *99 persons sick by 3.1, but not by 12.1 -- perhaps
                        had short-term illness and picked up in 12.2 -- check
                        sometime;

**use info to determine age and whether invalid in 1995;
gen invo60=age>60;
gen invu60=age<=60;
gen invo6095=age-1>60&dismos>=12;
gen invu6095=age-1<=60&dismos>=12;

egen byte diso60=sum(invo60), by(hhnum);
egen byte disu60=sum(invu60), by(hhnum);
egen byte diso6095=sum(invo6095), by(hhnum);
egen byte disu6095=sum(invu6095), by(hhnum);

sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum dis*;
sort hhnum;

merge hhnum using pexpdat;
drop adult; *not sure where this is from;
mvencode dis*, mv(0) ov;

egen child = rsum(ychild ochilm ochilf);
egen adult1 = rsum(adultm adultf elderm elderf);
replace adult1 = adult1-ov60;
replace ov60=ov60-diso60; *# non-invalid over 60s;
replace adult1=adult1-disu60; *# non-invalid adults;
egen disab = rsum(diso60 disu60);

egen child95 = rsum(ychild95 ochilm95 ochilf95);
egen adult195 = rsum(adultm95 adultf95 elderm95 elderf95); 
replace adult195 = adult195-ov6095;
replace ov6095=ov6095-diso6095; *# non-invalid over 60s;
replace adult195=adult195-disu6095; *# non-invalid adults;
egen disab95 = rsum(diso6095 disu6095);

keep hhnum settlm child* adult* ov60* dis*;

gen ent1=0;
replace ent1=2150+2150*ov60+2150*disab if adult1>0;
replace ent1=     2150*ov60+2150*disab if adult1==0;
replace ent1=ent1+408*(adult1-1)        if adult1>0;
replace ent1=ent1+510*child;
replace ent1=5375 if ent1>5375; *Vilma's method;

gen ent195=0;
replace ent195=1824+1824*ov6095+1824*disab95 if adult195>0;
replace ent195=     1824*ov6095+1824*disab95 if adult195==0;
replace ent195=ent195+365*(adult195-1)        if adult195>0;
replace ent195=ent195+456*child95;
replace ent195=4800 if ent195>4800; *Vilma's method - 1995;

gen adult2=adult1+ov60+disab;
gen ent2=0;
replace ent2=2150+408*(adult2-1)+510*child;
replace ent2=5375 if ent2>5375; *Our method;

gen adult295=adult195+ov6095+disab95;
gen ent295=0;
replace ent295=1824+365*(adult295-1)+456*child95;
replace ent295=4800 if ent295>4800; *Our method;

sort hhnum;
merge hhnum using pexpdat;
keep hhnum settlm child* adult* ov* dis* ent1 ent195 ent2 ent295
     NE NE95 penoa penoa95 ub ub95 landoa landoa95;
sort hhnum;

**recalculate max entitlements - 1
;
gen en1up=ent1-penoa-ub;
gen en1up95=ent195-penoa95-ub95;

gen en2up=ent2-penoa-ub;
gen en2up95=ent295-penoa95-ub95;

**recalculate max entitlements - 2
;
gen land=(landoa*1000/1500)*562; *assumes unit in survey is decare (1000sqm);
gen land95=(landoa95*1000/1500)*562;
gen en1upl=en1up-land;
gen en1upl95=en1up95-land95;

gen en2upl=en2up-land;
gen en2upl95=en2up95-land95;

replace en1upl=0 if en1upl<0;
replace en1upl95=0 if en1upl95<0;
replace en2upl=0 if en2upl<0;
replace en2upl95=0 if en2upl95<0;

*keep hhnum en*;
sort hhnum;

label var ent1     "NE entitle - Vilma's method";
label var ent195   "NE entitle - Vilma's method - 95";
label var ent2     "NE entitle - Our method";
label var ent295   "NE entitle - Our method - 95";
label var en1up    "NE entitle 1 - net of ub, pens";
label var en1up95  "NE entitle 1 - net of ub, pens - 95";
label var en2up    "NE entitle 2 - net of ub, pens";
label var en2up95  "NE entitle 2 - net of ub, pens - 95";
label var en1upl   "NE entitle 1 - net of ub, pens, land";
label var en1upl95 "NE entitle 1 - net of ub, pens, land - 95";
label var en2upl   "NE entitle 2 - net of ub, pens, land";
label var en2upl95 "NE entitle 2 - net of ub, pens, land - 95";

save entitle, replace;
 
log close;
