#delimit ;
cap log close;
log using do\expagg,replace;
*************************************************************;
*                                                           *;
*    Name     : EXPAGG.DO                                   *;
*    OBJECTIVE: Construction and analysis of aggregate      *;
*               expenditure                                 *;
*                                                           *;
*************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

use corehh;
keep hhnum hhsize;

merge hhnum using fdexp;
*tab _merge;
drop _merge;
sort hhnum;

merge hhnum using nfdexp;
*tab _merge;
drop _merge;
sort hhnum;

merge hhnum using durable;
replace durflow=0 if durflow==.;
*tab _merge;
drop _merge;
sort hhnum;

merge hhnum using rentimp;
*tab _merge;
drop _merge;
sort hhnum;

*gen foodx = fdexp - fprod;
*gen homcx = fprod;

gen food=fdexp;

egen tothhx1 = rsum(food imprent othous educul health transpo cloth remout 
                    other durflow); *complete expenditure measure;
egen tothhx2 = rsum(food imprent othous educul health transp cloth remout 
                    other); *without durable flow;
egen tothhx3 = rsum(food othous educul health transp cloth remout 
                    other); *without durable flow or imputed rent;

keep hhnum hhsize food imprent othous educul health transpo 
     cloth remout other durflow tothhx1 tothhx2 tothhx3;

order hhnum hhsize food imprent othous educul health transpo 
     cloth remout other durflow tothhx1 tothhx2 tothhx3;

format hhsize food imprent othous educul health transpo 
     cloth remout other durflow tothhx1 tothhx2 tothhx3
     %9.2f;


label variable food     "hh exp. Food";
label variable imprent  "hh exp. Imputed Rent";
label variable othous   "hh exp. O. Housing";
label variable educul   "hh exp. Education";
label variable health   "hh exp. Health";
label variable transpo  "hh exp. Trnsport";
label variable cloth    "hh exp. Clothing";
label variable remout   "hh exp. Remittances";
label variable other    "hh exp. Other";
label variable durflow  "hh exp. Durables flow";

label variable tothhx1 "Tot hh expend";
label variable tothhx2 "Tot hh expend - dur. not incl.";
label variable tothhx3 "Tot hh expend - dur. & imprent not incl.";


cap program drop temp1;
program define temp1;

gen `1's=0;
replace `1's = `1'/tothhx1 if `1'>0 & `1'~=.;  
gen `1'p=0;
replace `1'p = `1'/hhsize if `1'>0 & `1'~=.;

label variable `1's "Share for `1'";
label variable `1'p "Per capita Exp.for `1'";
format `1's `1'p %9.2f;

end;
temp1 food; temp1 imprent; temp1 othous; temp1 educul; temp1 health;
temp1 transpo; temp1 cloth; temp1 remout; temp1 other; temp1 durflow;

gen totpcx1 = tothhx1/hhsi;
gen totpcx2 = tothhx2/hhsi;
gen totpcx3 = tothhx3/hhsi;

label variable totpcx1 "Tot pc expend";
label variable totpcx2 "Tot pc expend - dur. not incl.";
label variable totpcx3 "Tot pc expend - dur. & imprent not incl.";

format totpc* %9.2f;

lab data "Total Aggreagate Expenditure";
sort hhnum;
sum, f;
save expagg, replace;

/*
use expagg, clear;

sum;
sum foods, det;
sum othouss, det;
sum educuls if educuls>0, det;
sum healths if healths>0, det;
sum transpos if transpos>0, det;
sum cloths, det;
sum remouts if remouts>0, det;
sum others, det;
sum durflows if durflows>0, det;
sum imprents, det;


list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if (foods<0.2|foods>0.9), nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if othouss==0, nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if educuls>0.1, nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if cloths==0, nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if others==0, nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if durflows>0.4, nodisp noobs;

**some new checks
;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if othouss>0.3, nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if healths>0.4, nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if transpos>0.4, nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if cloths>0.2, nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if others>0.4, nodisp noobs;
list hhnum foods imprents othouss educuls healths transpos 
     cloths remouts others durflows tothhx1
     if educuls>0.1, nodisp noobs;
*/

log close;
