#delimit ;
cap log close;
log using do\fdprice,replace;
*************************************************************;
*                                                           *;
*    Name    : FDPRICE.DO                                   *;
*    OBJECTIVE: Analyse price data, decide on outlier       *;
*               correction, create dataset with new prices  *;
*                                                           *;
*************************************************************;
clear;
set more 1;
set log linesize 132;
set display linesize 132;

***stages in the analysis:
   (1) outliers are defined as:
          (a) (>mean+3*sd and >3*mean) or <mean-3*sd, OR
          (b) (>mean+4*sd and >4*mean) or <mean-4*sd
   (2) outliers (and missing prices) are then replaced with median 
       (calculated over the observations without outliers).  
;

use sec10;

merge hhnum using corehh;
drop if _merge==1; *hh 460125 -- incomplete questionnaire;
keep hhnum bashki fooditem fdprice fpurqua;

replace fdprice=. if fdprice==0;*set zero prices to missing;

sort fooditem;
by fooditem: sum fdprice; *means of prices with outliers; 

**Make some adjustments to the price data -- these were suggested
  by Vilma
;
replace fdprice=fdprice*2 if fooditem==105 & 
                             (fdprice==35|fdprice==37|fdprice==40);
                             *pasta -- must be for 1/2kg;
*replace fdprice=fdprice*2 if fooditem==106 &
                             (fdprice==40|fdprice==45|fdprice==50);
                              *rice -- must be for 1/2kg;
*Harold didn't agree with the previous one;
replace fdprice=fdprice/10 if fooditem==801 &
                              (fdprice==200|fdprice==300|fdprice==350);
                              *fresh milk -- must be old LEK;
replace fdprice=fdprice/10 if fooditem==804 & (fdprice==240|fdprice==300);
                              *yoghurt -- must be old LEK;
replace fdprice=fdprice*10 if fooditem==1105 & (fdprice==70);
                              *tea -- must be coding error;

**Some further adjustments to the price data -- these were suggested
  by Harold
;
replace fdprice=fdprice*10 if fooditem==905 & fdprice==13; *vegoil;
replace fdprice=fdprice*10 if fooditem==1104 & 
                              (fdprice==50|fdprice==70); *coffee;

**The following rules for deciding whether a price obseveration is an 
  outlier or not were devised after looking at the prices with Vilma.
  They may have to be revised again after we receive all of the data.
;
egen mprice=mean(fdprice), by(fooditem);
egen sprice=sd(fdprice), by(fooditem);
sort fooditem;

**following is the 'default' way of identifying outliers;
gen upper = mprice+sprice*3;
gen lower = mprice-sprice*3;
gen poutlier=1 if (fdprice>upper & (fdprice>mprice*3) & fdprice~=.) |
                  (fdprice<lower);

**following is a more stringent definition of whether price is outlier
;
local criter1 "(fooditem==102|fooditem==104|fooditem==105|fooditem==106|
                fooditem==201|fooditem==303|fooditem==306|fooditem==410|
                fooditem==411|fooditem==601|fooditem==603|fooditem==605|
                fooditem==606|fooditem==701|fooditem==802|fooditem==901|
                fooditem==904|fooditem==905|fooditem==1103|fooditem==1104|
                fooditem==1201|fooditem==1204)";

replace upper = mprice+sprice*4 if `criter1';
replace lower = mprice-sprice*4 if `criter1';
replace poutlier=. if `criter1';
replace poutlier=1 if `criter1' & 
                  ((fdprice>upper & (fdprice>mprice*4) & fdprice~=.) |
                  (fdprice<lower));

replace poutlier=. if fooditem==702;*frozen fish -- only one case and 
                                      not outlier;

tab fooditem if poutlier==1; *# of occurences -- note: this contains observations
                             for those households who didn't purchase the 
                             food (later we'll turn these observations into 
                             missing values);

save tempdat1, replace;


**look at distribution of prices and list outliers**
;
use tempdat1, clear;

cap program drop temp1;

program define temp1;
  use tempdat1, clear;
  keep hhnum bashki fooditem fdprice poutlier upper lower mprice sprice;
  keep if fooditem==`1';
  sum fdprice, det;
  if `3'==1 {
            display "outliers are (>mean+3*sd and >3*mean) or <mean-3*sd"
            };             
  if `3'==2 {
            display "outliers are (>mean+4*sd and >4*mean) or <mean-4*sd"
            };             
  list if poutlier==1, nodisp;
end;

temp1 101 maize 1;
temp1 102 wheat 2;
temp1 103 bread(sm) 1;
temp1 104 bread(lg) 2;
temp1 105 pasta 2;
temp1 106 rice 2;
*temp1 107 othgrains;

temp1 201 beans 2;
temp1 202 potatos 1;
temp1 301 tomatos 1;
temp1 302 peppers 1;
temp1 303 eggplant 2;
temp1 304 onion 1;
temp1 305 olives 1;
temp1 306 othveg 2;

temp1 406 grapes 1;
temp1 407 watermelon 1;
temp1 410 othfrui 2;
temp1 411 othfrui 2;

temp1 501 canveg 1;
temp1 502 canfrui 1;
temp1 503 jams 1;
temp1 504 honey 1;

temp1 601 veal 2;
temp1 603 lamb 2;
temp1 604 chicken 1;
temp1 605 sausage 2;
temp1 606 eggs 2;
temp1 608 canmeat 1;
temp1 610 othmeat 1;

temp1 701 freshfish 2;
*temp1 702 frozfish;
temp1 703 canfish 1;

temp1 801 milk 1;
temp1 802 cheese 2;
temp1 804 yoghurt 1;
temp1 805 pow.milk 1;
temp1 806 othdairy 1;

temp1 901 butter 2;
temp1 902 margarine 1;
temp1 904 oliveoil 2;
temp1 905 vegoil. 2;
temp1 906 tallow 1;

temp1 1102 sugar 1;
temp1 1103 spices 2;
temp1 1104 coffee 2;
temp1 1105 tea 1;

temp1 1201 s.drinks 2;
temp1 1202 juice 1;
temp1 1204 wine 2;
temp1 1205 beer 1;
temp1 1206 raki 1;
temp1 1302 prepared 1;

use tempdat1, clear;

replace fdprice=. if poutlier==1&fpurqua==0;
replace poutlier=. if poutlier==1&fpurqua==0;
*we don't care that these households had outliers because they didn't
purchase and so can't really be expected to know the current price.  Note
that in our fax to Leka we queried him about some of these -- if he responds
then adjust;

tab fooditem if poutlier==1; *# of occurences of outliers -- note: does not
                             contain observations for those households who
                             didn't purchase the food;
                             
*replace fdprice=. if poutlier==1; *at present we're leaving outliers in;

*sort fooditem;
*by fooditem: sum fdprice; *prices without outliers;

**calculate medians without outliers;
sort bashki fooditem;
egen medianp=median(fdprice), by(bashki fooditem);
egen medianp2=median(fdprice), by(fooditem);

gen fdprice2=fdprice;
replace fdprice2=medianp if fdprice2==.;
replace fdprice2=medianp2 if fdprice2==.; 
*replace with median over fooditems if median over bashki doesn't exist.
Note - at present outliers are left in: only replace missing;  

*sort fooditem;
*by fooditem: sum fdprice2; *means of outlier adjusted prices;

sort hhnum fooditem;
keep hhnum fooditem fdprice fdprice2 poutlier;

**Notes on the data
;
note: For hhnum=100112 fooditem=1103, fdprice=70 -- this is very high
      but as the hh only consumes 1kg, we kept it as is;
note: It looked as if some of the very high priced small breads might in
      fact be large bread and vice-vera.  To check this we isolated these
      households using: 
      keep if (fooditem==103 & fdprice==60)|(fooditem==104 & fdprice<=25) 
      and looked at calories -- however they were within normal bounds and
      therefore nothing was done to the prices;

save fdprice, replace;

log close;

