#delimit ;
cap log close;
log using do\income,replace;
*************************************************************;
*                                                           *;
*    Name     : INCOME.DO                                   *;
*    OBJECTIVE: Construction of basic income measure        *;
*                                                           *;
*************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;


**wages
;
use sec041;
keep hhnum pcode w1weekhr w1weeksm w1netpay w1paytim w1transp w1bonus;
gen wagei=0;
replace wagei=w1weekhr*w1weeksm*w1netpay if w1paytim==1; *hourly pay;
replace wagei=w1weekhr*w1weeksm*(w1netpay/8) if w1paytim==2; *daily pay;
replace wagei=w1weeksm*w1netpay if w1paytim==3; *weekly pay;
replace wagei=w1weeksm*(w1netpay/2) if w1paytim==4; *bi-weekly pay;
replace wagei=w1weeksm*(w1netpay/4) if w1paytim==5; *monthly pay;

replace wagei=wagei+w1transp;
replace wagei=wagei+w1bonus;

egen wage=sum(wagei), by(hhnum);

sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum wage;
sort hhnum;
save tempy1, replace;

**non-agg. self employment income
;
use sec051;
keep hhnum pcode selfrev;
drop if selfrev==88;

egen nonagg=sum(selfrev), by(hhnum);

sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum nonagg;
sort hhnum;
save tempy2, replace;

*how to calculate income from agg??;

**remittances received
;
use sec071b;
keep hhnum rrl6mos;

gen remrecvi=rrl6mos/6;

egen remrec=sum(remrecvi), by(hhnum);

sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum remrec;
sort hhnum;
save tempy3, replace;


**social assistance
;
use sec081;
keep hhnum sacode sapay;

gen pension=sapay if sacode==1;

gen ub=sapay if sacode==5;

gen socassis=sapay if sacode==6;

egen othersa=sum(sapay) if (sacode==2|sacode==3|sacode==4|sacode==7|
                            sacode==8|sacode==9|sacode==10|sacode==11), by(hhnum);

replace othersa=.  if othersa==0;

egen a=mean(pension), by(hhnum);
egen b=mean(ub), by(hhnum);
egen c=mean(socassis), by(hhnum);
egen d=mean(othersa), by(hhnum);

sort hhnum;
qui by hhnum: keep if _n==1;

replace pension=a;
replace ub=b;
replace socassis=c;
replace othersa=d;

keep hhnum pension ub socassis othersa;
sort hhnum;
save tempy4, replace;

**property income
;
use sec092b;
keep hhnum realvren;

egen rentinc=sum(realvren), by(hhnum);
replace rentinc=rentinc/12;

sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum rentinc;
sort hhnum;
save tempy5, replace;

**add up components of income
;
use corehh;
keep hhnum hhsize settlm;

merge hhnum using tempy1;
tab _merge;
drop if _merge==2; *incomplete questionnaires;
drop _merge;
sort hhnum;

merge hhnum using tempy2;
tab _merge;
drop _merge;
sort hhnum;

merge hhnum using tempy3;
tab _merge;
drop _merge;
sort hhnum;

merge hhnum using tempy4;
tab _merge;
drop if _merge==2; *incomplete questionnaires;
drop _merge;
sort hhnum;

merge hhnum using tempy5;
tab _merge;
drop _merge;
sort hhnum;

replace wage=0     if wage==.;
replace nonagg=0   if nonagg==.;
replace remrec=0   if remrec==.;
replace pension=0  if pension==.;
replace ub=0       if ub==.;
replace socassis=0 if socassis==.;
replace othersa=0  if othersa==.;
replace rentinc=0  if rentinc==.;


**access to plot
;
merge hhnum using sec062a;
tab _merge;
drop if _merge==2; *incomplete questionnaires;
drop _merge rectype;

gen same=0;
sort hhnum;
qui by hhnum: replace same=1 if hhnum[_n+1]==hhnum[_n];
keep if same==0; *hhs 30103, 630741, 650323 duplicate obs.;
drop same;

sort hhnum;
save income, replace;


/*
use income;
merge hhnum using expann;

keep if un_p==100 & settlm==1;

count if wage>0;
count if nonagg>0;
count if remrec>0;
count if pension>0;
count if ub>0;
count if socassis>0;
count if othersa>0;
count if rentinc>0;
count if accesagl==1;

sum tothhx1p, det;

sum tothhx1p if wage==0 & nonagg==0 & remrec==0 & pension==0 & 
                ub==0 & socassis==0 & othersa==0 & othersa==0 &
                rentinc==0 & accesagl==0, det;

list hhnum  if wage==0 & nonagg==0 & remrec==0 & pension==0 & 
               ub==0 & socassis==0 & othersa==0 & othersa==0 &
               rentinc==0 & accesagl==0;
*/

log close;
