#delimit ;
cap log close;
log using do\inv7,replace;
***************************************************;
*                                                 *;
*    Name     : inv7.DO                         *;
*    OBJECTIVE: Receipt of NE regressions - rural - investigation *;
*                                                 *;
***************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;
set matsize 150;


***RURAL 1996: TYPE 2 TOBIT AND STANDARD TOBIT USING 'FULL' EXPENDITURE (BASE MODEL)***;
use nereg;
regress exp1_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        orc_ov pas_ov cro_ov
        fa_mac
        animlv animmv animsv

        if settlm==0;
predict pnnexpr if settlm==0;


**Heckman's two-stage using NE_pf**
;
**1st stage: derive estimate of alpha using probit
;
gen nerec=NE>0;
dprobit nerec
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        NE_pf
        
        if settlm==0;
probit;
sca logLprob=_result(2);

gen mills = _b[ychild]*ychild+_b[ochilm]*ochilm+_b[ochilf]*ochilf+
            _b[adultm]*adultm+_b[adultf]*adultf+
            _b[elderm]*elderm+_b[elderf]*elderf+
            _b[penoa]*penoa+_b[penot]*penot+
            _b[animv]*animv+
            _b[landov]*landov+
            _b[pnnexpr]*pnnexpr+
            _b[exp1_NE]*exp1_NE+_b[NE_pf]*NE_pf+
            _b[_cons];

replace mills = normd(mills)/normprob(mills);

**2nd stage
;
regress NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        NE_pf
        mills
        
        if settlm==0&NE>0;


**Heckman's two-stage using NE_ratio**
;
egen sumen=sum(en2upl), by(bashki);

gen d=1;
egen hhlds=sum(d), by(bashki);
gen en_pf= sumen/hhlds;

gen NE_ratio=NE_pf/en_pf;

**1st stage: derive estimate of alpha using probit
;
dprobit nerec
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        /*pnnexpr exp1_NE*/
        NE_ratio
        
        if settlm==0;
probit;
sca logLprob=_result(2);

drop mills;
gen mills = _b[ychild]*ychild+_b[ochilm]*ochilm+_b[ochilf]*ochilf+
            _b[adultm]*adultm+_b[adultf]*adultf+
            _b[elderm]*elderm+_b[elderf]*elderf+
            _b[penoa]*penoa+_b[penot]*penot+
            _b[animv]*animv+
            _b[landov]*landov+
            /*_b[pnnexpr]*pnnexpr+_b[exp1_NE]*exp1_NE+*/
            _b[NE_ratio]*NE_ratio+
            _b[_cons];
replace mills = normd(mills)/normprob(mills);

**2nd stage
;
regress NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        /*pnnexpr exp1_NE*/
        NE_ratio
        mills
        
        if settlm==0&NE>0;


/*
**Test restrictions of standard Tobit
;
*standard tobit;
tobit   NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        NE_pf
        
        if settlm==0, ll;
sca logLtob=_result(2);

*truncated regression;
tobit   NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        
        if settlm==0&NE>0, ll(0);
sca logLttob=_result(2);

/*
**check whether this is really truncated regression by re-constructing
  the log-likelihood using estimated paramters
;
count if settlm==0&NE>0;
sca numrec=_result(1);
sca sighat=_b[_se];
 
gen xib = _b[ychild]*ychild+_b[ochilm]*ochilm+_b[ochilf]*ochilf+
           _b[adultm]*adultm+_b[adultf]*adultf+
           _b[elderm]*elderm+_b[elderf]*elderf+
           _b[penoa]*penoa+_b[penot]*penot+
           _b[animv]*animv+
           _b[landov]*landov+
           _b[pnnexpr]*pnnexpr+
           _b[exp1_NE]*exp1_NE+
           _b[_cons];

sca part1 = -numrec/2*(log(2*_pi)+log(sighat^2));

gen temp1 = (NE-xib)^2;
egen temp2 = sum(temp1) if NE>0&settlm==0;
sca part2 = 1/(sighat^2)*temp2;

gen temp3 = normprob(xib);
replace temp3=log(temp3);
egen part3 = sum(temp3) if NE>0&settlm==0;
sca part3=part3;

sca logL3 = part1 - part2 - part3;
*/
/*
**estimate truncated regression using ML -- do this because not sure
  cnreg doing the correct thing
;
regress NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        
        if settlm==0&NE>0;
mat ival = get(_b);
local se = _result(9);
mat se=J(1,1,`se');

mat ival=ival,se;

cap program drop trunc0;
program define trunc0;
      local lnf    "`1'";
      local xbeta  "`2'";
      local zgamma "`3'";
      quietly replace `lnf' = -(1/2)*(log(2*_pi)+log(`zgamma'^2))
                              -1/(`zgamma'^2)*($S_mldepn-`xbeta')^2
                              -log(normprob(`xbeta'));
end;


ml begin;
ml function trunc0;
ml method lf;
eq      NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE;
eq lnalpha :;
ml model b = NE lnalpha, dep(10) from(ival);
mat list b;
ml sample mysamp if NE>0&settlm==0;
ml search, limits (NE 0 6000 lnalpha -1 1);
ml max f V;
ml post truncreg, title(MLE of truncated regression);
ml mlout truncreg; 
*/

*truncation ignored (just for fun);
regress NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        
        if settlm==0&NE>0;


**construct test statistic - remember, H0 is that restrictions of standard
  Tobit are valid;

sca LR = -2*(logLtob-(logLprob+logLttob));
*sca list LR;
sca list logLtob logLprob logLttob;

sca pval = chiprob(14,LR);

di in gr "Chi-sq(14) = " in ye %8.2f LR;
di in gr "Prob > Chi-sq = " in ye %8.3f pval;



**Correct for Heterosked in Type 2 Tobit and standard Tobit
;
**2nd stage of Type 2 Tobit, robustly estimated 
;
regress NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        temp
        
        if settlm==0&NE>0, robust;

regress NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        temp
        
        if settlm==0&NE>0, robust cluster(bashki);

**Standard Tobit, robustly estimated 
;
tobit   NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        
        if settlm==0, ll robust; *note: doesn't work;

tobit   NE
        ychild ochilm ochilf adultm adultf elderm elderf
        penoa penot
        animv
        landov
        pnnexpr exp1_NE
        
        if settlm==0, ll robust cluster(bashki); *note: doesn't work;
*/

log close;
