#delimit ;
cap log close;
log using do\labhist,replace;
*************************************************************;
*                                                           *;
*    Name     : LABHIST.DO                                  *;
*    OBJECTIVE: Create data on labor history.  Note: there  *;
*               is no info on migrants (they weren't in 3.3)*;
*************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

use adult;

*keep if hhnum==101025|hhnum==400520|hhnum==400316;

*keep if wapop==1;

keep hhnum pcode intermon absdumm
     gender age 
     edulevel educlast
     difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob othertyp otherenm
     othereny otherlng
     lfs1a wapop workwage;

gen lfs=lfs1a; drop lfs1a;
recode lfs 1 4=1
           2 5=2
           3 6=3;*remove distinction between working age and retired;
*modify to distinguish wage employment;
recode lfs 1=1
           2=3
           3=4;
replace lfs=2 if lfs==1&workwage==0;

replace lfs=5 if absdumm==1;

label define lfs
1 "wage emp"
2 "n.wage e"
3 "unemp"
4 "NILF"
5 "absent"
;
label value lfs lfs;
label variable lfs "current labor force status";

sort hhnum pcode;
save temp1, replace;

gen lfsa=.;
replace lfsa=1 if (joptype1>=1&joptype1<=6); *wage job;
replace lfsa=2 if ((joptype1>=7&joptype1<=10)|joptype1==13); *non-wage job;
replace lfsa=3 if joptype1==15;
replace lfsa=4 if ((joptype1>=11&joptype1<=12)|joptype1==14);
replace lfsa=8 if joptype1==16;

gen lfsb=.;
replace lfsb=1 if (othertyp>=1&othertyp<=6);
replace lfsb=2 if ((othertyp>=7&othertyp<=10)|othertyp==13);
replace lfsb=3 if othertyp==15;
replace lfsb=4 if ((othertyp>=11&othertyp<=12)|othertyp==14);
replace lfsb=8 if othertyp==16;

gen int_m  = 96*12+intermon;       *interview 'month';
gen job1_m = jobenye1*12+jobenme1; *'month' job1 ended;
gen job2_m = othereny*12+otherenm; *'month' job2 ended;

gen int_joba = int_m-job1_m;
gen int_jobb = int_m-job2_m;

gen diffjoba=difjobe1;
gen diffjobb=otherjob;

gen joblenga=joblnge1;
gen joblengb=otherlng;


***Make some fixes to the data***
;

**fix cases where joblengb missing -- use assumption that person started job
  b the month after finishing job a -- affects 4 people 
;
gen mark=0;
replace mark=1 if diffjobb==1&joblengb==.&int_joba~=.&int_jobb~=.;
list hhnum pcode diffjoba diffjobb int_joba int_jobb joblengb if mark==1, nodisp;
replace joblengb=int_joba-int_jobb-1 if mark==1;
list hhnum pcode diffjoba diffjobb int_joba int_jobb joblengb if mark==1, nodisp;
drop mark;

**fix cases where (int_jobb+joblengb)>=int_joba -- use assumption that person 
  started job b the month after finishing job a (this is really only for
  accounting purposes -- only few cases where (int_jobb+joblengb)>int_joba;
;
gen mark=0;
replace mark=1 if diffjobb==1&(int_jobb+joblengb)>=int_joba&int_joba~=.&int_jobb~=.;
list hhnum pcode diffjoba diffjobb int_joba int_jobb joblengb if mark==1, nodisp;
replace joblengb=int_joba-int_jobb-1 if mark==1;
list hhnum pcode diffjoba diffjobb int_joba int_jobb joblengb if mark==1, nodisp;
drop mark;

**make fix to sec 3.3 data for young people who must have been students
;
gen mark=0;
replace mark=1 if age<=19 & diffjoba==0 & educlast==1 & (lfs==1|lfs==2|lfs==3);
replace diffjoba=1    if mark==1;
replace lfsa=4        if mark==1;
replace int_joba=4    if mark==1; *assume last sem ended 4 months ago?;
replace joblenga=1001 if mark==1; *ensures student for whole of history;
drop mark;
*these people were in education last semester but in sec. 3.3 said had been
 in same 'occupation' since election -- change so were in education.  Should
 affect 8 people.  The problem here may be that we are classifying students 
 as employed, just because they worked in last 7 days, but perhaps they are 
 on holidays?  Check this.  Also -- problem with estimation of duration of
 being student above - wonky?;

gen mark=0;
replace mark=1 if (age-4)<13 & diffjoba==0 & edulevel==5 & (lfs==1|lfs==2|lfs==3);
replace diffjoba=1              if mark==1;
replace lfsa=4                  if mark==1;
replace int_joba=(age-13)*12    if mark==1;
replace joblenga=1002           if mark==1;
drop mark;
gen mark=0;
replace mark=1 if (age-4)<17 & diffjoba==0 & edulevel==6 & (lfs==1|lfs==2|lfs==3);
replace diffjoba=1              if mark==1;
replace lfsa=4                  if mark==1;
replace int_joba=(age-17)*12    if mark==1;
replace joblenga=1002           if mark==1;
drop mark;
gen mark=0;
replace mark=1 if (age-4)<17 & diffjoba==0 & edulevel==7 & (lfs==1|lfs==2|lfs==3);
replace diffjoba=1              if mark==1;
replace lfsa=4                  if mark==1;
replace int_joba=(age-17)*12    if mark==1;
replace joblenga=1003           if mark==1;
drop mark;
gen mark=0;
replace mark=1 if (age-4)<19 & diffjoba==0 & edulevel==8 & (lfs==1|lfs==2|lfs==3);
replace diffjoba=1              if mark==1;
replace lfsa=4                  if mark==1;
replace int_joba=(age-19)*12    if mark==1;
replace joblenga=1004           if mark==1;
drop mark;
*have assumed the following minimum ages for completion of education:
 middle - 13, secondary(gen.) - 17, secondary(tech.) - 17, 
 post-second. - 19.  These were found from median ages of those who completed
 in the last semester (check how valid these are).  Post-second was set to 17+2
 because no-one had just completed.  The above people are re-classified as 
 being students at time of 1st election, eventhough they said had same 
 occupation as now.  Note: the problem could be the same as above -- we 
 classified them as presently working but in fact they are just working on 
 holiday;

**fix sec 3.3 data for those who were students in previous occ., diffjobb~=1,
  have termination point, but joblnge1=. -- assume all periods prior to
  termination point, person was also student -- affects 23 persons
;
gen mark=0;
replace mark=1 if joptype1==11 & diffjobb~=1 & joblenga==. & int_joba~=.;
replace joblenga=1000 if mark==1;
list hhnum pcode joptype1 diffjoba diffjobb int_joba int_jobb joblengb if mark==1, nodisp;
drop mark;
 
**fix sec 3.3 data for those with int_joba>=48, but joblenga=. -- affects
  4 persons
;
gen mark=0;
replace mark=1 if int_joba>=48 & int_joba~=. & diffjobb~=1 & joblenga==.;
replace joblenga=1000 if mark==1;
list hhnum pcode joptype1 diffjoba diffjobb int_joba int_jobb joblengb if mark==1, nodisp;
drop mark;


***Start the construction of the labor history variables
;

cap program drop temp1;
program define temp1;

gen j_01`1'=9; gen j_03`1'=9; gen j_06`1'=9; gen j_12`1'=9; 
gen j_18`1'=9; gen j_24`1'=9; gen j_36`1'=9; gen j_48`1'=9;
gen j_60`1'=9;

replace j_60`1'=lfs if diffjob`1'==0;
replace j_48`1'=lfs if diffjob`1'==0;
replace j_36`1'=lfs if diffjob`1'==0;
replace j_24`1'=lfs if diffjob`1'==0;
replace j_18`1'=lfs if diffjob`1'==0;
replace j_12`1'=lfs if diffjob`1'==0;
replace j_06`1'=lfs if diffjob`1'==0;
replace j_03`1'=lfs if diffjob`1'==0;
replace j_01`1'=lfs if diffjob`1'==0; *same job at all previous points;  

**establish point of termination of job held at election (if different from
  one held now)
;
*60;local crit1 "diffjob`1'==1 & int_job`1'>=60 & int_job`1'~=."; *need last item b/c of missing info;
*48;local crit2 "diffjob`1'==1 & int_job`1'>=48 & int_job`1'<=59"; 
*36;local crit3 "diffjob`1'==1 & int_job`1'>=36 & int_job`1'<=47";
*24;local crit4 "diffjob`1'==1 & int_job`1'>=24 & int_job`1'<=35";
*18;local crit5 "diffjob`1'==1 & int_job`1'>=18 & int_job`1'<=23";
*12;local crit6 "diffjob`1'==1 & int_job`1'>=12 & int_job`1'<=17";
*06;local crit7 "diffjob`1'==1 & int_job`1'>=6  & int_job`1'<=11";
*03;local crit8 "diffjob`1'==1 & int_job`1'>=3  & int_job`1'<=5";
*01;local crit9 "diffjob`1'==1 & int_job`1'>=0  & int_job`1'<=2";

replace j_60`1'=lfs`1' if `crit1';
replace j_48`1'=lfs`1' if `crit2';
replace j_36`1'=lfs`1' if `crit3'; 
replace j_24`1'=lfs`1' if `crit4';
replace j_18`1'=lfs`1' if `crit5';
replace j_12`1'=lfs`1' if `crit6'; 
replace j_06`1'=lfs`1' if `crit7'; 
replace j_03`1'=lfs`1' if `crit8';
replace j_01`1'=lfs`1' if `crit9';


**fill out history prior to termination of first (different) job
;
gen dum1`1'=0; *term. happened in 01;
gen dum2`1'=0; *term. happened in 03;
gen dum3`1'=0; *term. happened in 06;
gen dum4`1'=0; *term. happened in 12;
gen dum5`1'=0; *term. happened in 18;
gen dum6`1'=0; *term. happened in 24;
gen dum7`1'=0; *term. happened in 36;
gen dum8`1'=0; *term. happened in 48;
gen dum9`1'=0; *term. happened in 60;
replace dum9`1'=1 if `crit1';*had (different) job ending in this period;
replace dum8`1'=1 if `crit2' &dum9`1'==0;
replace dum7`1'=1 if `crit3' &dum8`1'==0&dum9`1'==0; 
replace dum6`1'=1 if `crit4' &dum7`1'==0&dum8`1'==0&dum9`1'==0; 
replace dum5`1'=1 if `crit5' &dum6`1'==0&dum7`1'==0&dum8`1'==0&dum9`1'==0; 
replace dum4`1'=1 if `crit6' &dum5`1'==0&dum6`1'==0&dum7`1'==0&dum8`1'==0&dum9`1'==0; 
replace dum3`1'=1 if `crit7' &dum4`1'==0&dum5`1'==0&dum6`1'==0&dum7`1'==0&dum8`1'==0&dum9`1'==0; 
replace dum2`1'=1 if `crit8' &dum3`1'==0&dum4`1'==0&dum5`1'==0&dum6`1'==0&dum7`1'==0&dum8`1'==0&dum9`1'==0; 
replace dum1`1'=1 if `crit9' &dum2`1'==0&dum3`1'==0&dum4`1'==0&dum5`1'==0&dum6`1'==0&dum7`1'==0&dum8`1'==0&dum9`1'==0; 

replace j_60`1'=lfs`1' if dum8`1'==1 & (int_job`1'+jobleng`1')>=60&(int_job`1'+jobleng`1')~=.;

replace j_60`1'=lfs`1' if dum7`1'==1 & (int_job`1'+jobleng`1')>=60&(int_job`1'+jobleng`1')~=.;
replace j_48`1'=lfs`1' if dum7`1'==1 & (int_job`1'+jobleng`1')>=48&(int_job`1'+jobleng`1')~=.;

replace j_60`1'=lfs`1' if dum6`1'==1 & (int_job`1'+jobleng`1')>=60&(int_job`1'+jobleng`1')~=.;
replace j_48`1'=lfs`1' if dum6`1'==1 & (int_job`1'+jobleng`1')>=48&(int_job`1'+jobleng`1')~=.;
replace j_36`1'=lfs`1' if dum6`1'==1 & (int_job`1'+jobleng`1')>=36&(int_job`1'+jobleng`1')~=.;

replace j_60`1'=lfs`1' if dum5`1'==1 & (int_job`1'+jobleng`1')>=60&(int_job`1'+jobleng`1')~=.;
replace j_48`1'=lfs`1' if dum5`1'==1 & (int_job`1'+jobleng`1')>=48&(int_job`1'+jobleng`1')~=.;
replace j_36`1'=lfs`1' if dum5`1'==1 & (int_job`1'+jobleng`1')>=36&(int_job`1'+jobleng`1')~=.;
replace j_24`1'=lfs`1' if dum5`1'==1 & (int_job`1'+jobleng`1')>=24&(int_job`1'+jobleng`1')~=.;

replace j_60`1'=lfs`1' if dum4`1'==1 & (int_job`1'+jobleng`1')>=60&(int_job`1'+jobleng`1')~=.;
replace j_48`1'=lfs`1' if dum4`1'==1 & (int_job`1'+jobleng`1')>=48&(int_job`1'+jobleng`1')~=.;
replace j_36`1'=lfs`1' if dum4`1'==1 & (int_job`1'+jobleng`1')>=36&(int_job`1'+jobleng`1')~=.;
replace j_24`1'=lfs`1' if dum4`1'==1 & (int_job`1'+jobleng`1')>=24&(int_job`1'+jobleng`1')~=.;
replace j_18`1'=lfs`1' if dum4`1'==1 & (int_job`1'+jobleng`1')>=18&(int_job`1'+jobleng`1')~=.;

replace j_60`1'=lfs`1' if dum3`1'==1 & (int_job`1'+jobleng`1')>=60&(int_job`1'+jobleng`1')~=.;
replace j_48`1'=lfs`1' if dum3`1'==1 & (int_job`1'+jobleng`1')>=48&(int_job`1'+jobleng`1')~=.;
replace j_36`1'=lfs`1' if dum3`1'==1 & (int_job`1'+jobleng`1')>=36&(int_job`1'+jobleng`1')~=.;
replace j_24`1'=lfs`1' if dum3`1'==1 & (int_job`1'+jobleng`1')>=24&(int_job`1'+jobleng`1')~=.;
replace j_18`1'=lfs`1' if dum3`1'==1 & (int_job`1'+jobleng`1')>=18&(int_job`1'+jobleng`1')~=.;
replace j_12`1'=lfs`1' if dum3`1'==1 & (int_job`1'+jobleng`1')>=12&(int_job`1'+jobleng`1')~=.;

replace j_60`1'=lfs`1' if dum2`1'==1 & (int_job`1'+jobleng`1')>=60&(int_job`1'+jobleng`1')~=.;
replace j_48`1'=lfs`1' if dum2`1'==1 & (int_job`1'+jobleng`1')>=48&(int_job`1'+jobleng`1')~=.;
replace j_36`1'=lfs`1' if dum2`1'==1 & (int_job`1'+jobleng`1')>=36&(int_job`1'+jobleng`1')~=.;
replace j_24`1'=lfs`1' if dum2`1'==1 & (int_job`1'+jobleng`1')>=24&(int_job`1'+jobleng`1')~=.;
replace j_18`1'=lfs`1' if dum2`1'==1 & (int_job`1'+jobleng`1')>=18&(int_job`1'+jobleng`1')~=.;
replace j_12`1'=lfs`1' if dum2`1'==1 & (int_job`1'+jobleng`1')>=12&(int_job`1'+jobleng`1')~=.;
replace j_06`1'=lfs`1' if dum2`1'==1 & (int_job`1'+jobleng`1')>=06&(int_job`1'+jobleng`1')~=.;

replace j_60`1'=lfs`1' if dum1`1'==1 & (int_job`1'+jobleng`1')>=60&(int_job`1'+jobleng`1')~=.;
replace j_48`1'=lfs`1' if dum1`1'==1 & (int_job`1'+jobleng`1')>=48&(int_job`1'+jobleng`1')~=.;
replace j_36`1'=lfs`1' if dum1`1'==1 & (int_job`1'+jobleng`1')>=36&(int_job`1'+jobleng`1')~=.;
replace j_24`1'=lfs`1' if dum1`1'==1 & (int_job`1'+jobleng`1')>=24&(int_job`1'+jobleng`1')~=.;
replace j_18`1'=lfs`1' if dum1`1'==1 & (int_job`1'+jobleng`1')>=18&(int_job`1'+jobleng`1')~=.;
replace j_12`1'=lfs`1' if dum1`1'==1 & (int_job`1'+jobleng`1')>=12&(int_job`1'+jobleng`1')~=.;
replace j_06`1'=lfs`1' if dum1`1'==1 & (int_job`1'+jobleng`1')>=06&(int_job`1'+jobleng`1')~=.;
replace j_03`1'=lfs`1' if dum1`1'==1 & (int_job`1'+jobleng`1')>=03&(int_job`1'+jobleng`1')~=.;

**fill in lfs for periods later than last termination
;
replace j_48`1'=lfs if j_48`1'==9 & j_60`1'~=9;
replace j_36`1'=lfs if j_36`1'==9 & j_48`1'~=9;
replace j_24`1'=lfs if j_24`1'==9 & j_36`1'~=9;
replace j_18`1'=lfs if j_18`1'==9 & j_24`1'~=9;
replace j_12`1'=lfs if j_12`1'==9 & j_18`1'~=9;
replace j_06`1'=lfs if j_06`1'==9 & j_12`1'~=9;
replace j_03`1'=lfs if j_03`1'==9 & j_06`1'~=9;
replace j_01`1'=lfs if j_01`1'==9 & j_03`1'~=9;

end;
temp1 a; temp1 b;

**create final j variables
;
gen j_01=j_01a; gen j_03=j_03a; gen j_06=j_06a; gen j_12=j_12a; 
gen j_18=j_18a; gen j_24=j_24a; gen j_36=j_36a; gen j_48=j_48a;
gen j_60=j_60a;

replace j_01=j_01b if diffjobb==1 & j_01b~=9;
replace j_03=j_03b if diffjobb==1 & j_03b~=9;
replace j_06=j_06b if diffjobb==1 & j_06b~=9;
replace j_12=j_12b if diffjobb==1 & j_12b~=9;
replace j_18=j_18b if diffjobb==1 & j_18b~=9;
replace j_24=j_24b if diffjobb==1 & j_24b~=9;
replace j_36=j_36b if diffjobb==1 & j_36b~=9;
replace j_48=j_48b if diffjobb==1 & j_48b~=9;
replace j_60=j_48b if diffjobb==1 & j_60b~=9;

cap program drop temp2;
program define temp2;

label define j_`1'
9 "indet."
1 "emp,wage"
2 "emp,non-wage"
3 "unemp"
4 "NILF"
5 "absent"
8 "other"
;
label value j_`1' j_`1';
label variable j_`1' "lfs - `1' month(s) ago";

end;
temp2 01; temp2 03; temp2 06; temp2 12; temp2 18; 
temp2 24; temp2 36; temp2 48; temp2 60; 

**Following tries to fix cases where j_*=9 and person was obviously a 
  student.  Only a few people are affected by this.  I have given a bit
  of leeway -- age has to be <=minage+1.  This can perhaps be extended
  to minage+2
;
gen minage=999;
replace minage=13 if edulevel==5;
replace minage=17 if edulevel==6;
replace minage=17 if edulevel==7;
replace minage=19 if edulevel==8;
replace minage=21 if edulevel==9;

gen mark=0;
replace mark=1 if j_01==9           & (age-(1/12))<=minage+1 & minage~=999;
replace j_01=3 if mark==1;
replace j_03=3 if mark==1;
replace j_06=3 if mark==1;
replace j_12=3 if mark==1;
replace j_18=3 if mark==1;
replace j_24=3 if mark==1;
replace j_36=3 if mark==1;
replace j_48=3 if mark==1;
drop mark;
gen mark=0;
replace mark=1 if j_03==9 & j_01~=9 & (age-(3/12))<=minage+1 & minage~=999;
replace j_03=3 if mark==1;
replace j_06=3 if mark==1;
replace j_12=3 if mark==1;
replace j_18=3 if mark==1;
replace j_24=3 if mark==1;
replace j_36=3 if mark==1;
replace j_48=3 if mark==1;
drop mark;
gen mark=0;
replace mark=1 if j_06==9 & j_03~=9 & (age-(6/12))<=minage+1 & minage~=999;
replace j_06=3 if mark==1;
replace j_12=3 if mark==1;
replace j_18=3 if mark==1;
replace j_24=3 if mark==1;
replace j_36=3 if mark==1;
replace j_48=3 if mark==1;
drop mark;
gen mark=0;
replace mark=1 if j_12==9 & j_06~=9 & (age-(12/12))<=minage+1 & minage~=999;
replace j_12=3 if mark==1;
replace j_18=3 if mark==1;
replace j_24=3 if mark==1;
replace j_36=3 if mark==1;
replace j_48=3 if mark==1;
drop mark;
gen mark=0;
replace mark=1 if j_18==9 & j_12~=9 & (age-(18/12))<=minage+1 & minage~=999;
replace j_18=3 if mark==1;
replace j_24=3 if mark==1;
replace j_36=3 if mark==1;
replace j_48=3 if mark==1;
drop mark;
gen mark=0;
replace mark=1 if j_24==9 & j_18~=9 & (age-(24/12))<=minage+1 & minage~=999;
replace j_24=3 if mark==1;
replace j_36=3 if mark==1;
replace j_48=3 if mark==1;
drop mark;
gen mark=0;
replace mark=1 if j_36==9 & j_24~=9 & (age-(36/12))<=minage+1 & minage~=999;
replace j_36=3 if mark==1;
replace j_48=3 if mark==1;
drop mark;
gen mark=0;
replace mark=1 if j_48==9 & j_36~=9 & (age-(48/12))<=minage+1 & minage~=999;
replace j_48=3 if mark==1;
drop mark;

keep hhnum pcode absdumm
     gender age minage 
     edulevel educlast
     lfs lfsa lfsb
     diffjoba diffjobb int_joba int_jobb joblenga joblengb
     j_*
     dum*
     wapop;

sort hhnum pcode;

save labhist, replace;


use labhist;

tab lfs j_01;
tab lfs j_03;
tab lfs j_06;
tab lfs j_12;
tab lfs j_18;
tab lfs j_24;
tab lfs j_36;
tab lfs j_48;

/*
use labhist;

tab lfs j_01 if wapop==1;
tab lfs j_03 if wapop==1;
tab lfs j_06 if wapop==1;
tab lfs j_12 if wapop==1;
tab lfs j_18 if wapop==1;
tab lfs j_24 if wapop==1;
tab lfs j_36 if wapop==1;
tab lfs j_48 if wapop==1;

tab lfs j_01 if wapop==0;
tab lfs j_03 if wapop==0;
tab lfs j_06 if wapop==0;
tab lfs j_12 if wapop==0;
tab lfs j_18 if wapop==0;
tab lfs j_24 if wapop==0;
tab lfs j_36 if wapop==0;
tab lfs j_48 if wapop==0;
*/
/*
use labhist;
merge hhnum pcode using adult;

list hhnum pcode age edulevel lfs difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob 
     othertyp otherenm othereny otherlng if j_01==9, noobs nodisp;
list hhnum pcode age edulevel lfs difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob 
     othertyp otherenm othereny otherlng if j_03==9&j_01~=9, noobs nodisp;
list hhnum pcode age edulevel lfs difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob 
     othertyp otherenm othereny otherlng if j_06==9&j_03~=9, noobs nodisp;
list hhnum pcode age edulevel lfs difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob 
     othertyp otherenm othereny otherlng if j_12==9&j_06~=9, noobs nodisp;
list hhnum pcode age edulevel lfs difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob 
     othertyp otherenm othereny otherlng if j_18==9&j_12~=9, noobs nodisp;
list hhnum pcode age edulevel lfs difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob 
     othertyp otherenm othereny otherlng if j_24==9&j_18~=9, noobs nodisp;
list hhnum pcode age edulevel lfs difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob 
     othertyp otherenm othereny otherlng if j_36==9&j_24~=9, noobs nodisp;
list hhnum pcode age edulevel lfs difjobe1 joptype1 jobenme1 jobenye1 joblnge1 otherjob 
     othertyp otherenm othereny otherlng if j_48==9&j_36~=9, noobs nodisp;
*/
/*
*good test of program;
list hhnum pcode 
     gender age 
     edlevel educlast
     lfs lfsa lfsb
     diffjoba diffjobb int_joba int_jobb joblenga joblengb
     if diffjobb==1 & hhnum==20717 & pcode==3;
list j_01a j_03a j_06a j_12a j_18a j_24a j_36a j_48a
     if diffjobb==1 & hhnum==20717 & pcode==3, noobs nodisp;
list j_01b j_03b j_06b j_12b j_18b j_24b j_36b j_48b
     if diffjobb==1 & hhnum==20717 & pcode==3, noobs nodisp;
list j_01 j_03 j_06 j_12 j_18 j_24 j_36 j_48
     if diffjobb==1 & hhnum==20717 & pcode==3, noobs nodisp;
list hhnum pcode 
     gender age 
     edlevel educlast
     lfs lfsa lfsb
     diffjoba diffjobb int_joba int_jobb joblenga joblengb
     if diffjobb==1 & hhnum==40126 & pcode==3;
list j_01a j_03a j_06a j_12a j_18a j_24a j_36a j_48a
     if diffjobb==1 & hhnum==40126 & pcode==3, noobs nodisp;
list j_01b j_03b j_06b j_12b j_18b j_24b j_36b j_48b
     if diffjobb==1 & hhnum==40126 & pcode==3, noobs nodisp;
list j_01 j_03 j_06 j_12 j_18 j_24 j_36 j_48
     if diffjobb==1 & hhnum==40126 & pcode==3, noobs nodisp;
list hhnum pcode 
     gender age 
     edlevel educlast
     lfs lfsa lfsb
     diffjoba diffjobb int_joba int_jobb joblenga joblengb
     if diffjobb==1 & hhnum==50411 & pcode==3;
list j_01a j_03a j_06a j_12a j_18a j_24a j_36a j_48a
     if diffjobb==1 & hhnum==50411 & pcode==3, noobs nodisp;
list j_01b j_03b j_06b j_12b j_18b j_24b j_36b j_48b
     if diffjobb==1 & hhnum==50411 & pcode==3, noobs nodisp;
list j_01 j_03 j_06 j_12 j_18 j_24 j_36 j_48
     if diffjobb==1 & hhnum==50411 & pcode==3, noobs nodisp;


list hhnum pcode 
     gender age 
     edlevel educlast
     lfs lfsa lfsb
     diffjoba diffjobb int_joba int_jobb joblenga joblengb /*dum**/
     if diffjobb==1 & hhnum==101025 & pcode==3;
list j_01a j_03a j_06a j_12a j_18a j_24a j_36a j_48a
     if diffjobb==1 & hhnum==101025 & pcode==3, noobs nodisp;
list j_01b j_03b j_06b j_12b j_18b j_24b j_36b j_48b
     if diffjobb==1 & hhnum==101025 & pcode==3, noobs nodisp;
list j_01 j_03 j_06 j_12 j_18 j_24 j_36 j_48
     if diffjobb==1 & hhnum==101025 & pcode==3, noobs nodisp;
list hhnum pcode 
     gender age 
     edlevel educlast
     lfs lfsa lfsb
     diffjoba diffjobb int_joba int_jobb joblenga joblengb /*dum**/
     if diffjobb==1 & hhnum==400520 & pcode==5;
list j_01a j_03a j_06a j_12a j_18a j_24a j_36a j_48a
     if diffjobb==1 & hhnum==400520 & pcode==5, noobs nodisp;
list j_01b j_03b j_06b j_12b j_18b j_24b j_36b j_48b
     if diffjobb==1 & hhnum==400520 & pcode==5, noobs nodisp;
list j_01 j_03 j_06 j_12 j_18 j_24 j_36 j_48
     if diffjobb==1 & hhnum==400520 & pcode==5, noobs nodisp;
list hhnum pcode 
     gender age 
     edlevel educlast
     lfs lfsa lfsb
     diffjoba diffjobb int_joba int_jobb joblenga joblengb /*dum**/
     if diffjobb==1 & hhnum==400316 & pcode==3;
list j_01a j_03a j_06a j_12a j_18a j_24a j_36a j_48a
     if diffjobb==1 & hhnum==400316 & pcode==3, noobs nodisp;
list j_01b j_03b j_06b j_12b j_18b j_24b j_36b j_48b
     if diffjobb==1 & hhnum==400316 & pcode==3, noobs nodisp;
list j_01 j_03 j_06 j_12 j_18 j_24 j_36 j_48
     if diffjobb==1 & hhnum==400316 & pcode==3, noobs nodisp;

*/





log close;


