#delimit ;
cap log close;
log using do\land,replace;
*************************************************************;
*                                                           *;
*    Name     : LAND.DO                                     *;
*    OBJECTIVE: Farm assets (land) data for                 *;
*               predicted expenditure regressions           *;
*************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

**check of the land ownership 'accounting'
;
use hhnum bashki region using corehh;

merge hhnum using sec062b;
tab _merge;
drop if _merge==2; *incomplete questionnaires;
drop _merge;
sort hhnum;

merge hhnum using sec062c;
tab _merge;
drop if _merge==2; *incomplete questionnaires;
drop _merge;
sort hhnum;

gen orc_oa=alowna1;
gen pas_oa=alowna2;
gen cro_oa=alowna3;

gen orcb_96=alobt961;
gen pasb_96=alobt962;
gen crob_96=alobt963;
gen orcb_95=alobt951;
gen pasb_95=alobt952;
gen crob_95=alobt953;
gen orcb_94=alobt941;
gen pasb_94=alobt942;
gen crob_94=alobt943;
gen orcb_93=alobt931;
gen pasb_93=alobt932;
gen crob_93=alobt933;

gen orcs_96=alsol961;
gen pass_96=alsol962;
gen cros_96=alsol963;
gen orcs_95=alsol951;
gen pass_95=alsol952;
gen cros_95=alsol953;
gen orcs_94=alsol941;
gen pass_94=alsol942;
gen cros_94=alsol943;
gen orcs_93=alsol931;
gen pass_93=alsol932;
gen cros_93=alsol933;

**land distribution from state
;
gen orcd_96=0;
replace orcd_96=alcoopa1 if alcoopy1==96;
gen pasd_96=0;
replace pasd_96=alcoopa2 if alcoopy2==96;
gen crod_96=0;
replace crod_96=alcoopa3 if alcoopy3==96;

gen orcd_95=0;
replace orcd_95=alcoopa1 if alcoopy1==95;
gen pasd_95=0;
replace pasd_95=alcoopa2 if alcoopy2==95;
gen crod_95=0;
replace crod_95=alcoopa3 if alcoopy3==95;

gen orcd_94=0;
replace orcd_94=alcoopa1 if alcoopy1==94;
gen pasd_94=0;
replace pasd_94=alcoopa2 if alcoopy2==94;
gen crod_94=0;
replace crod_94=alcoopa3 if alcoopy3==94;

gen orcd_93=0;
replace orcd_93=alcoopa1 if alcoopy1<=93;
gen pasd_93=0;
replace pasd_93=alcoopa2 if alcoopy2<=93;
gen crod_93=0;
replace crod_93=alcoopa3 if alcoopy3<=93;

mvencode orc* pas* cro*, mv(0) ov;

gen orc_oa95=orc_oa-orcd_96-orcb_96+orcs_96;
gen orc_oa94=orc_oa95-orcd_95-orcb_95+orcs_95;
gen orc_oa93=orc_oa94-orcd_94-orcb_94+orcs_94;
gen orc_oa92=orc_oa93-orcd_93-orcb_93+orcs_93;

gen pas_oa95=pas_oa-pasd_96-pasb_96+pass_96;
gen pas_oa94=pas_oa95-pasd_95-pasb_95+pass_95;
gen pas_oa93=pas_oa94-pasd_94-pasb_94+pass_94;
gen pas_oa92=pas_oa93-pasd_93-pasb_93+pass_93;

gen cro_oa95=cro_oa-crod_96-crob_96+cros_96;
gen cro_oa94=cro_oa95-crod_95-crob_95+cros_95;
gen cro_oa93=cro_oa94-crod_94-crob_94+cros_94;
gen cro_oa92=cro_oa93-crod_93-crob_93+cros_93;

**fix to the data -- only a few cases affected -- need to write note on this
;
replace orc_oa92=0 if orc_oa92<0;
replace pas_oa92=0 if pas_oa92<0;
replace cro_oa92=0 if cro_oa92<0;

egen landoa  =rsum(orc_oa   pas_oa   cro_oa  );
egen landoa95=rsum(orc_oa95 pas_oa95 cro_oa95);
egen landoa94=rsum(orc_oa94 pas_oa94 cro_oa94);
egen landoa93=rsum(orc_oa93 pas_oa93 cro_oa93);
egen landoa92=rsum(orc_oa92 pas_oa92 cro_oa92);

**transition indicators
;
gen dorc_96=orc_oa~=orc_oa95;
gen dorc_95=orc_oa95~=orc_oa94;
gen dorc_94=orc_oa94~=orc_oa93;
gen dorc_93=orc_oa93~=orc_oa92;

gen dpas_96=pas_oa~=pas_oa95;
gen dpas_95=pas_oa95~=pas_oa94;
gen dpas_94=pas_oa94~=pas_oa93;
gen dpas_93=pas_oa93~=pas_oa92;

gen dcro_96=cro_oa~=cro_oa95;
gen dcro_95=cro_oa95~=cro_oa94;
gen dcro_94=cro_oa94~=cro_oa93;
gen dcro_93=cro_oa93~=cro_oa92;

gen orc_ov=alownv1;
gen pas_ov=alownv2;
gen cro_ov=alownv3;

**irrigation variables
;
gen orc_irr=alwater1;
recode orc_irr   1=0
               2/5=1
               ; 
gen pas_irr=alwater2;
recode pas_irr   1=0
               2/5=1
               ; 
gen cro_irr=alwater3;
recode cro_irr   1=0
               2/5=1
               ;

gen orc_ovu=orc_ov/orc_oa;*unit values of land -- only hhs owning;
gen pas_ovu=pas_ov/pas_oa;
gen cro_ovu=cro_ov/cro_oa;

**impute unit land prices for all with value missing and unit value<=1000
  (these are in fax to Leka)
;
replace orc_ovu=. if orc_ovu<=1000;
replace pas_ovu=. if pas_ovu<=1000;
replace cro_ovu=. if cro_ovu<=1000;

**impute unit land prices for some outliers (these are all in fax to Leka)
;
replace orc_ovu=. if hhnum==240509;
replace pas_ovu=. if hhnum==240509;
replace cro_ovu=. if hhnum==240509;
replace orc_ovu=. if hhnum==240510;
replace pas_ovu=. if hhnum==240128;
replace cro_ovu=. if hhnum==20204;
replace cro_ovu=. if hhnum==470230;
replace cro_ovu=. if hhnum==630320;

sort bashki;
egen medorch=median(orc_ovu), by(bashki);
egen medorch2=median(orc_ovu);
egen medpast=median(pas_ovu), by(bashki);
egen medpast2=median(pas_ovu);
egen medcrop=median(cro_ovu), by(bashki);
egen medcrop2=median(cro_ovu);

gen orc_ovu2=orc_ovu; *unit values for *all* hhs;
gen pas_ovu2=pas_ovu;
gen cro_ovu2=cro_ovu;

replace orc_ovu2=medorch  if orc_ovu==.;
replace orc_ovu2=medorch2 if orc_ovu2==.;
replace pas_ovu2=medpast  if pas_ovu==.;
replace pas_ovu2=medpast2 if pas_ovu2==.;
replace cro_ovu2=medcrop  if cro_ovu==.;
replace cro_ovu2=medcrop2 if cro_ovu2==.;
*replace with country-wide median if median over bashki doesn't exist;

**re-calculate land value for land currently owned (note: only changes
  should be for those with missing value for value)
;
replace orc_ov=orc_oa*orc_ovu2;
replace pas_ov=pas_oa*pas_ovu2;
replace cro_ov=cro_oa*cro_ovu2;

**calculate value of past holdings
;

gen orc_ov95=orc_oa95*orc_ovu2;
gen orc_ov94=orc_oa94*orc_ovu2;
gen orc_ov93=orc_oa93*orc_ovu2;
gen orc_ov92=orc_oa92*orc_ovu2;

gen pas_ov95=pas_oa95*pas_ovu2;
gen pas_ov94=pas_oa94*pas_ovu2;
gen pas_ov93=pas_oa93*pas_ovu2;
gen pas_ov92=pas_oa92*pas_ovu2;

gen cro_ov95=cro_oa95*cro_ovu2;
gen cro_ov94=cro_oa94*cro_ovu2;
gen cro_ov93=cro_oa93*cro_ovu2;
gen cro_ov92=cro_oa92*cro_ovu2;

egen landov  =rsum(orc_ov   pas_ov   cro_ov  );
egen landov95=rsum(orc_ov95 pas_ov95 cro_ov95);
egen landov94=rsum(orc_ov94 pas_ov94 cro_ov94);
egen landov93=rsum(orc_ov93 pas_ov93 cro_ov93);
egen landov92=rsum(orc_ov92 pas_ov92 cro_ov92);

label var orc_oa   "area of owned land - orchards";
label var orc_oa95 "area of owned land - orchards - 95";
label var orc_oa94 "area of owned land - orchards - 94";
label var orc_oa93 "area of owned land - orchards - 93";
label var orc_oa92 "area of owned land - orchards - 92";
label var pas_oa   "area of owned land - pasture";
label var pas_oa95 "area of owned land - pasture - 95";
label var pas_oa94 "area of owned land - pasture - 94";
label var pas_oa93 "area of owned land - pasture - 93";
label var pas_oa92 "area of owned land - pasture - 92";
label var cro_oa   "area of owned land - crops";
label var cro_oa95 "area of owned land - crops - 95";
label var cro_oa94 "area of owned land - crops - 94";
label var cro_oa93 "area of owned land - crops - 93";
label var cro_oa92 "area of owned land - crops - 92";
label var landoa   "area of owned land";
label var landoa95 "area of owned land - 95";
label var landoa94 "area of owned land - 94";
label var landoa93 "area of owned land - 93";
label var landoa92 "area of owned land - 92";

label var orc_ov   "val. of owned land - orchards";
label var orc_ov95 "val. of owned land - orchards - 95";
label var orc_ov94 "val. of owned land - orchards - 94";
label var orc_ov93 "val. of owned land - orchards - 93";
label var orc_ov92 "val. of owned land - orchards - 92";
label var pas_ov   "val. of owned land - pasture";
label var pas_ov95 "val. of owned land - pasture - 95";
label var pas_ov94 "val. of owned land - pasture - 94";
label var pas_ov93 "val. of owned land - pasture - 93";
label var pas_ov92 "val. of owned land - pasture - 92";
label var cro_ov   "val. of owned land - crops";
label var cro_ov95 "val. of owned land - crops - 95";
label var cro_ov94 "val. of owned land - crops - 94";
label var cro_ov93 "val. of owned land - crops - 93";
label var cro_ov92 "val. of owned land - crops - 92";
label var landov   "value of owned land";
label var landov95 "value of owned land - 95";
label var landov94 "value of owned land - 94";
label var landov93 "value of owned land - 93";
label var landov92 "value of owned land - 92";

label var orc_irr "orchards - 0=rain,1=irrigated";
label var pas_irr "pastures - 0=rain,1=irrigated";
label var cro_irr "crops    - 0=rain,1=irrigated";
label var orc_ovu  "unit value of orchards";
label var pas_ovu  "unit value of pasture";
label var cro_ovu  "unit value of crops";

keep hhnum orc_o* pas_o* cro_o* d* land* orc_irr pas_irr cro_irr ;
sort hhnum;
save land, replace;


log close;


