#delimit ;
cap log close;
log using do\lforce,replace;
******************************************************;
*                                                    *;
*    Name     : LFORCE.DO                            *;
*    OBJECTIVE: Labor force status data for          *;
*               predicted expenditure regressions    *;
******************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

**current and historic labor force status variables - these variables include absent
  hh members, but not migrants
;
use hhnum pcode lfs j_12 j_24 j_36 using labhist;

gen id=1;

egen a = sum(id) if lfs==1|lfs==2, by(hhnum);
egen emp = mean(a), by(hhnum);
drop a;
egen a = sum(id) if lfs==1, by(hhnum);
egen empwag = mean(a), by(hhnum);
drop a;
egen a = sum(id) if lfs==2, by(hhnum);
egen empnwg = mean(a), by(hhnum);
drop a;
egen a = sum(id) if lfs==5, by(hhnum);
egen absent = mean(a), by(hhnum);
drop a;

egen a = sum(id) if j_12==1|j_12==2, by(hhnum);
egen emp95 = mean(a), by(hhnum);
drop a;
egen a = sum(id) if j_12==1, by(hhnum);
egen empwag95 = mean(a), by(hhnum);
drop a;
egen a = sum(id) if j_12==2, by(hhnum);
egen empnwg95 = mean(a), by(hhnum);
drop a;
egen a = sum(id) if j_12==5, by(hhnum);
egen absent95 = mean(a), by(hhnum);
drop a;

egen a = sum(id) if j_24==1|j_24==2, by(hhnum);
egen emp94 = mean(a), by(hhnum);
drop a;
egen a = sum(id) if j_24==1, by(hhnum);
egen empwag94 = mean(a), by(hhnum);
drop a;
egen a = sum(id) if j_24==2, by(hhnum);
egen empnwg94 = mean(a), by(hhnum);
drop a;
egen a = sum(id) if j_24==5, by(hhnum);
egen absent94 = mean(a), by(hhnum);
drop a;

egen a = sum(id) if j_36==1|j_36==2, by(hhnum);
egen emp93 = mean(a), by(hhnum);
drop a;
egen a = sum(id) if j_36==1, by(hhnum);
egen empwag93 = mean(a), by(hhnum);
drop a;
egen a = sum(id) if j_36==2, by(hhnum);
egen empnwg93 = mean(a), by(hhnum);
drop a;
egen a = sum(id) if j_36==5, by(hhnum);
egen absent93 = mean(a), by(hhnum);
drop a;

sort hhnum; 
qui by hhnum: keep if _n==1;

mvencode emp* absent*, mv(0) ov;

label variable emp      "# employed (present) hh members";
label variable emp95    "# employed hh members - 95";
label variable emp94    "# employed hh members - 94";
label variable emp93    "# employed hh members - 93";
label variable empwag   "# wage employed (present) hh members";
label variable empwag95 "# wage employed hh members - 95";
label variable empwag94 "# wage employed hh members - 94";
label variable empwag93 "# wage employed hh members - 93";
label variable empnwg   "# non-wage employed (present) hh members";
label variable empnwg95 "# non-wage employed hh members - 95";
label variable empnwg94 "# non-wage employed hh members - 94";
label variable empnwg93 "# non-wage employed hh members - 93";
label variable absent   "# absent hh members";
label variable absent95 "# absent hh members - 95";
label variable absent94 "# absent hh members - 94";
label variable absent93 "# absent hh members - 93";

keep hhnum emp* absent*;
sort hhnum;


save lforce, replace;

log close;


