#delimit ;
cap log close;
log using do\livestck,replace;
*************************************************************;
*                                                           *;
*    Name     : LIVESTCK.DO                                 *;
*    OBJECTIVE: Farm assets (livestock) data for            *;
*               predicted expenditure regressions           *;
*************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

use hhnum bashki region using corehh;

merge hhnum using sec064;
tab _merge;
drop if _merge==2; *incomplete questionnaires;
drop _merge;

drop lvcoop*;

**correction to the data (still need to get this verified by Leka)
;
replace lvown5=7 if hhnum==666654;

mvencode lv*, mv(0) ov;

gen animl   = lvown1+lvown4;
gen animm   = lvown2+lvown3+lvown5;
gen anims   = lvown6;
gen animl95 = lvlsum1+lvlsum4;
gen animm95 = lvlsum2+lvlsum3+lvlsum5;
gen anims95 = lvlsum6;
gen animl94 = lv2sum1+lv2sum4;
gen animm94 = lv2sum2+lv2sum3+lv2sum5;
gen anims94 = lv2sum6;
gen animl93 = lv3sum1+lv3sum4;
gen animm93 = lv3sum2+lv3sum3+lv3sum5;
gen anims93 = lv3sum6;

**Use following prices from sheet that Harold got from Albania
  cattle=31107
  sheep=5223
  goats=3577
  horse=35000 
  pigs=11000 
  poultry=270 -- median price of chicken/kg is 180 Lek -- H said 
                 assume avg. chicken weighs 1.5kg
;
gen animlv   = lvown1*31107+lvown4*35000;
gen animmv   = lvown2*5223+lvown3*3577+lvown5*11000;
gen animsv   = lvown6*270;
gen animlv95 = lvlsum1*31107+lvlsum4*35000;
gen animmv95 = lvlsum2*5223+lvlsum3*3577+lvlsum5*11000;
gen animsv95 = lvlsum6*270;
gen animlv94 = lv2sum1*31107+lv2sum4*35000;
gen animmv94 = lv2sum2*5223+lv2sum3*3577+lv2sum5*11000;
gen animsv94 = lv2sum6*270;
gen animlv93 = lv3sum1*31107+lv3sum4*35000;
gen animmv93 = lv3sum2*5223+lv3sum3*3577+lv3sum5*11000;
gen animsv93 = lv3sum6*270;

gen anim   =animl  +animm  +anims;
gen anim95 =animl95+animm95+anims95;
gen anim94 =animl94+animm94+anims94;
gen anim93 =animl93+animm93+anims93;
gen animv  =animlv  +animmv  +animsv;
gen animv95=animlv95+animmv95+animsv95;
gen animv94=animlv94+animmv94+animsv94;
gen animv93=animlv93+animmv93+animsv93;

**transition indicators
;
gen d_anl  =animl  ~=animl95;
gen d_anl95=animl95~=animl94;
gen d_anl94=animl94~=animl93;

gen d_anm  =animm  ~=animm95;
gen d_anm95=animm95~=animm94;
gen d_anm94=animm94~=animm93;

gen d_ans  =anims  ~=anims95;
gen d_ans95=anims95~=anims94;
gen d_ans94=anims94~=anims93;

label var animl   "# cattle, horses, donkeys";
label var animm   "# sheep, goats, pigs";
label var anims   "# poultry";
label var animl95 "# cattle, horses, donkeys - 95";
label var animm95 "# sheep, goats, pigs - 95";
label var anims95 "# poultry - 95";
label var animl94 "# cattle, horses, donkeys - 94";
label var animm94 "# sheep, goats, pigs - 94";
label var anims94 "# poultry - 94";
label var animl93 "# cattle, horses, donkeys - 93";
label var animm93 "# sheep, goats, pigs - 93";
label var anims93 "# poultry - 93";

label var animlv   "value cattle, horses, donkeys";
label var animmv   "value sheep, goats, pigs";
label var animsv   "value poultry";
label var animlv95 "value cattle, horses, donkeys - 95";
label var animmv95 "value sheep, goats, pigs - 95";
label var animsv95 "value poultry - 95";
label var animlv94 "value cattle, horses, donkeys - 94";
label var animmv94 "value sheep, goats, pigs - 94";
label var animsv94 "value poultry - 94";
label var animlv93 "value cattle, horses, donkeys - 93";
label var animmv93 "value sheep, goats, pigs - 93";
label var animsv93 "value poultry - 93";

label var anim   "number of animals";
label var anim95 "number of animals - 95";
label var anim94 "number of animals - 94";
label var anim93 "number of animals - 93";

label var animv   "value of animals";
label var animv95 "value of animals - 95";
label var animv94 "value of animals - 94";
label var animv93 "value of animals - 93";

keep hhnum anim* d*;
sort hhnum;
save livestck, replace;


log close;


