#delimit ;
cap log close;
log using do\neexp,replace;
*************************************************************;
*                                                           *;
*    Name     : NEEXP.DO                                    *;
*    OBJECTIVE: Social assistance and expenditure data for  *;
*               predicted expenditure regressions           *;
*************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

use sec081;
keep hhnum sacode sapay sa95pay sa94pay sa93pay;
keep if sacode==1|sacode==2|sacode==3|sacode==5|sacode==6;

gen penoa  =sapay if sacode==1;
gen penoa95=sa95pay if sacode==1;
gen penoa94=sa94pay if sacode==1;
gen penoa93=sa93pay if sacode==1;

egen penot   =sum(sapay) if sacode==2|sacode==3, by(hhnum);
egen penot95 =sum(sa95pay) if sacode==2|sacode==3, by(hhnum);
egen penot94 =sum(sa94pay) if sacode==2|sacode==3, by(hhnum);
egen penot93 =sum(sa93pay) if sacode==2|sacode==3, by(hhnum);

gen NE=sapay if sacode==6;
gen NE95=sa95pay if sacode==6;
gen NE94=sa94pay if sacode==6;
gen NE93=sa93pay if sacode==6;

gen ub=sapay if sacode==5;
gen ub95=sa95pay if sacode==5;
gen ub94=sa94pay if sacode==5;
gen ub93=sa93pay if sacode==5;

egen a=mean(penoa), by(hhnum);
egen b=mean(penoa95), by(hhnum);
egen c=mean(penoa94), by(hhnum);
egen d=mean(penoa93), by(hhnum);

egen e=mean(penot), by(hhnum);
egen f=mean(penot95), by(hhnum);
egen g=mean(penot94), by(hhnum);
egen h=mean(penot93), by(hhnum);

egen i=mean(NE), by(hhnum);
egen j=mean(NE95), by(hhnum);
egen k=mean(NE94), by(hhnum);
egen l=mean(NE93), by(hhnum);

egen m=mean(ub), by(hhnum);
egen n=mean(ub95), by(hhnum);
egen o=mean(ub94), by(hhnum);
egen p=mean(ub93), by(hhnum);

sort hhnum;
qui by hhnum: keep if _n==1;

replace penoa=a;
replace penoa95=b;
replace penoa94=c;
replace penoa93=d;

replace penot=e;
replace penot95=f;
replace penot94=g;
replace penot93=h;

replace NE=i;
replace NE95=j;
replace NE94=k;
replace NE93=l;

replace ub=m;
replace ub95=n;
replace ub94=o;
replace ub93=p;

keep hhnum pen* NE* ub*;
sort hhnum;

merge hhnum using expagg;
tab _merge;
drop if _merge==1;

mvencode pen* NE* ub*, mv(0) ov;

gen penoar=penoa>0;
gen penoa95r=penoa95>0;
gen penoa94r=penoa94>0;
gen penoa93r=penoa93>0;

gen penotr=penot>0;
gen penot95r=penot95>0;
gen penot94r=penot94>0;
gen penot93r=penot93>0;

gen exp1_NE=tothhx1-NE;
gen exp2_NE=tothhx2-NE;
gen exp3_NE=tothhx3-NE;


label var penoa   "amount of old age pension";
label var penoa95 "amount of old age pension - 95";
label var penoa94 "amount of old age pension - 94";
label var penoa93 "amount of old age pension - 93";
label var penot   "amount of other pension";
label var penot95 "amount of other pension - 95";
label var penot94 "amount of other pension - 94";
label var penot93 "amount of other pension - 93";

label var penoar   "dummy - hh receives old age pension";
label var penoa95r "dummy - hh received old age pension - 95";
label var penoa94r "dummy - hh received old age pension - 94";
label var penoa93r "dummy - hh received old age pension - 93";
label var penotr   "dummy - hh receives other pension";
label var penot95r "dummy - hh received other pension - 95";
label var penot94r "dummy - hh received other pension - 94";
label var penot93r "dummy - hh received other pension - 93";

label var NE      "social assistance received";
label var NE95    "social assistance received - 95";
label var NE94    "social assistance received - 94";
label var NE93    "social assistance received - 93";

label var ub      "unemployment benefits received";
label var ub95    "unemployment benefits received - 95";
label var ub94    "unemployment benefits received - 94";
label var ub93    "unemployment benefits received - 93";

label var exp1_NE  "tothhx1 less NE";
label var exp2_NE  "tothhx2 less NE";
label var exp3_NE  "tothhx3 less NE";

keep hhnum pen* NE* ub* tothhx* exp1_NE exp2_NE exp3_NE;
sort hhnum;
save neexp, replace;

log close;
