#delimit ;
cap log close;
log using do\nereg,replace;
**************************************************************;
*                                                            *;
*    Name     : NEREG.DO                                     *;
*    OBJECTIVE: Construct data for receipt of NE regressions *;
*                                                            *;
**************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;
set matsize 150;

use j:\datahous\fromcase\commsurv;
*community survey data from Anne C.;
drop commune;
sort bashcode;

merge bashcode using j:\datahous\fromcase\mrgcomm;
*this is used to link community survey with MOL data;
tab _m; drop _m;
sort prefect commune;

merge prefect commune using j:\datahous\fromcase\merge96;
tab _m; *keep if _m==3; drop _m;
sort bashcode;

merge bashcode using j:\datahous\fromcase\emaildat;
*this is extra MOL data that Anne C. forgot to include & sent later.  Note,
 I added the urban data to this by hand -- used the spreadsheet gusht96.xls
 that I got from Harold -- for rural this matches Anne's email;
tab _m; drop _m;
*keep bashcode bashki pop93 totfun96 totfun95;
sort bashki;

merge bashki using j:\datahous\dta\sample;
*data from sampler.xls.  Note, data for urban is from spreadsheet titled
 Albania sample.  I got this from Carlo and calc. #hhs using hhsize from
 survey and population from this spreadsheet (MOL data);
tab _m; keep if _m==3; drop _m; 
sort bashki;
save temp1, replace;

use pexpdat;
sort bashki;

merge bashki using temp1;
tab _m; drop _m;
sort hhnum;

merge hhnum using entitle;
tab _m; drop _m;
sort hhnum;

merge hhnum using durable;
tab _m; drop _m;
sort hhnum;

merge hhnum using rentimp;
tab _m; drop _m;
sort hhnum;

save nereg, replace;

**RURAL 1996 predicted expenditure
;
use nereg;
regress exp1_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        orc_ov pas_ov cro_ov
        fa_mac
        animlv animmv animsv

        if settlm==0;
predict pexp1r if settlm==0;
test nfaveh nfaoth nfainv fa_mac;

regress exp2_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        orc_ov pas_ov cro_ov
        fa_mac
        animlv animmv animsv
        durhh durelec durtrans

        if settlm==0;
predict pexp2r if settlm==0;
test nfaveh nfaoth nfainv fa_mac
     durhh durelec durtrans;

regress exp3_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        orc_ov pas_ov cro_ov
        fa_mac
        animlv animmv animsv
        durhh durelec durtrans
        hhtype1 hhtype2 rooms toilet1 toilet2 toilet7 water1

        if settlm==0;
predict pexp3r if settlm==0;
test nfaveh nfaoth nfainv fa_mac
     durhh durelec durtrans
     hhtype1 hhtype2 rooms toilet1 toilet2 toilet7 water1;

areg exp3_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        orc_ov pas_ov cro_ov
        fa_mac
        animlv animmv animsv
        durhh durelec durtrans
        hhtype1 hhtype2 rooms toilet1 toilet2 toilet7 water1

        if settlm==0,
        absorb(bashki);
predict pexp4r if settlm==0;

keep hhnum pexp1r pexp2r pexp3r pexp4r;
sort hhnum;
save tempr96, replace;

**URBAN 1996 predicted expenditure
;
use nereg;
regress exp1_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        landov
        fa_mac
        animv

        if settlm==1;
predict pexp1u if settlm==1;
test nfaveh nfaoth nfainv fa_mac;

regress exp2_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        landov
        fa_mac
        animv
        durhh durelec durtrans

        if settlm==1;
predict pexp2u if settlm==1;
test nfaveh nfaoth nfainv fa_mac
     durhh durelec durtrans;

regress exp3_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        landov
        fa_mac
        animv
        durhh durelec durtrans
        hhtype1 hhtype2 rooms toilet1 toilet2 toilet7 water1

        if settlm==1;
predict pexp3u if settlm==1;
test nfaveh nfaoth nfainv fa_mac
     durhh durelec durtrans
     hhtype1 hhtype2 rooms toilet1 toilet2 toilet7 water1;

keep hhnum pexp1u pexp2u pexp3u;
sort hhnum;
save tempu96, replace;

**RURAL 1995 predicted expenditure
;
use nereg;
regress exp1_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        orc_ov pas_ov cro_ov
        fa_mac
        animlv animmv animsv

        if settlm==0;

cap program drop temp;
prog define temp;
      local varlist "required existing min(1)";
      parse "`*'";
      parse "`varlist'", parse(" ");
      local i 1;
      while "``i''" ~= "" {;
            di in green _n "Replacing variable -``i''- with its 1995 value, OK?";
            replace ``i''=``i''95;
            local i = `i' + 1;
      };
end;

temp ychild ochilm ochilf adultm adultf elderm elderf
     primm primf middlm middlf seconm seconf highm highf
     penoa penot
     nfaveh nfaoth nfainv
     orc_ov pas_ov cro_ov
     fa_mac
     animlv animmv animsv;

predict pexp1r95 if settlm==0;

keep hhnum pexp1r95;
sort hhnum;
save tempr95a, replace;

use nereg;
regress exp2_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        orc_ov pas_ov cro_ov
        fa_mac
        animlv animmv animsv
        durhh durelec durtrans

        if settlm==0;

temp ychild ochilm ochilf adultm adultf elderm elderf
     primm primf middlm middlf seconm seconf highm highf
     penoa penot
     nfaveh nfaoth nfainv
     orc_ov pas_ov cro_ov
     fa_mac
     animlv animmv animsv;

predict pexp2r95 if settlm==0;

keep hhnum pexp2r95;
sort hhnum;
save tempr95b, replace;

use nereg;
regress exp3_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        orc_ov pas_ov cro_ov
        fa_mac
        animlv animmv animsv
        durhh durelec durtrans
        hhtype1 hhtype2 rooms toilet1 toilet2 toilet7 water1

        if settlm==0;

temp ychild ochilm ochilf adultm adultf elderm elderf
     primm primf middlm middlf seconm seconf highm highf
     penoa penot
     nfaveh nfaoth nfainv
     orc_ov pas_ov cro_ov
     fa_mac
     animlv animmv animsv;

predict pexp3r95 if settlm==0;

keep hhnum pexp3r95;
sort hhnum;
save tempr95c, replace;

**URBAN 1995 predicted expenditure
;
use nereg;
regress exp1_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        landov
        fa_mac
        animv

        if settlm==1;

temp ychild ochilm ochilf adultm adultf elderm elderf
     primm primf middlm middlf seconm seconf highm highf
     penoa penot
     nfaveh nfaoth nfainv
     landov
     fa_mac
     animv;

predict pexp1u95 if settlm==1;

keep hhnum pexp1u95;
sort hhnum;
save tempu95a, replace;

use nereg;
regress exp2_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        landov
        fa_mac
        animv
        durhh durelec durtrans

        if settlm==1;

temp ychild ochilm ochilf adultm adultf elderm elderf
     primm primf middlm middlf seconm seconf highm highf
     penoa penot
     nfaveh nfaoth nfainv
     landov
     fa_mac
     animv;

predict pexp2u95 if settlm==1;

keep hhnum pexp2u95;
sort hhnum;
save tempu95b, replace;

use nereg;
regress exp3_NE
        ychild ochilm ochilf adultm adultf elderm elderf
        primm primf middlm middlf seconm seconf highm highf
        penoa penot
        nfaveh nfaoth nfainv
        landov
        fa_mac
        animv
        durhh durelec durtrans
        hhtype1 hhtype2 rooms toilet1 toilet2 toilet7 water1

        if settlm==1;

temp ychild ochilm ochilf adultm adultf elderm elderf
     primm primf middlm middlf seconm seconf highm highf
     penoa penot
     nfaveh nfaoth nfainv
     landov
     fa_mac
     animv;

predict pexp3u95 if settlm==1;

keep hhnum pexp3u95;
sort hhnum;
save tempu95c, replace;


use nereg;

merge hhnum using tempr96;
tab _m; drop _m;
sort hhnum;

merge hhnum using tempu96;
tab _m; drop _m;
sort hhnum;

merge hhnum using tempr95a;
tab _m; drop _m;
sort hhnum;

merge hhnum using tempr95b;
tab _m; drop _m;
sort hhnum;

merge hhnum using tempr95c;
tab _m; drop _m;
sort hhnum;

merge hhnum using tempu95a;
tab _m; drop _m;
sort hhnum;

merge hhnum using tempu95b;
tab _m; drop _m;
sort hhnum;

merge hhnum using tempu95c;
tab _m; drop _m;
sort hhnum;

merge hhnum using corehh; *get sector & commutem variables;

*make some changes to dummy variables, as suggested by Harold;
replace toilet2=toilet2+toilet3+toilet4+toilet5;

replace pop93=6000 if pop93==.; *replace using sampler.xls;

replace totfun96=618  if bashki==9;
replace totfun96=1210 if bashki==45; *these are from community survey -- 
                                      replace missing values from MOL data;

gen NE_pf=totfun96*1000/numhhs; *totfun96 is in 1000s;
gen NE_pf95=totfun95*1000/numhhs; *totfun95 is in 1000s;

keep hhnum bashki sector settlm commutem exp* NE* en* p*
        ychild* ochilm* ochilf* adultm* adultf* elderm* elderf*
        primm* primf* middlm* middlf* seconm* seconf* highm* highf*
        penoa* penot*
        nfaveh* nfaoth* nfainv*
        orc_ov* pas_ov* cro_ov* landov*
        fa_mac*
        animlv* animmv* animsv* animv*
        empwag*
        durhh durelec durtrans
        hhtype1 hhtype2 rooms toilet1 toilet2 toilet7 water1;
sort hhnum;

save nereg, replace;


log close;
