#delimit ;
cap log close;
log using do\nfassets,replace;
*************************************************************;
*                                                           *;
*    Name     : NFASSETS.DO                                 *;
*    OBJECTIVE: Non-farm business assets data for           *;
*               predicted expenditure regressions           *;
*************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

use sec052a;

**fix data - 3 cases
;
replace bassown=1 if bassown==0&bassvalu~=.;

keep if bassown==1;

replace basspown=100 if basspown==0|basspown==.; *'0' - q answered incorrectly?;
replace bassvalu=bassvalu*(basspown/100);

egen av=sum(bassvalu)   if (bassitem>=8&bassitem<=13), by(hhnum);
egen a96v=sum(bassvalu) if (bassitem>=8&bassitem<=13)&bassacqy==96, by(hhnum);
egen a95v=sum(bassvalu) if (bassitem>=8&bassitem<=13)&bassacqy==95, by(hhnum);
egen a94v=sum(bassvalu) if (bassitem>=8&bassitem<=13)&bassacqy==94, by(hhnum);
egen a93v=sum(bassvalu) if (bassitem>=8&bassitem<=13)&bassacqy==93, by(hhnum);
egen ao=sum(bassvalu)   if (bassitem<8|bassitem>13), by(hhnum);
egen a96o=sum(bassvalu) if (bassitem<8|bassitem>13)&bassacqy==96, by(hhnum);
egen a95o=sum(bassvalu) if (bassitem<8|bassitem>13)&bassacqy==95, by(hhnum);
egen a94o=sum(bassvalu) if (bassitem<8|bassitem>13)&bassacqy==94, by(hhnum);
egen a93o=sum(bassvalu) if (bassitem<8|bassitem>13)&bassacqy==93, by(hhnum);

egen nfaveh    = mean(av), by (hhnum); 
egen nfaac96v  = mean(a96v), by (hhnum); 
egen nfaac95v  = mean(a95v), by (hhnum);
egen nfaac94v  = mean(a94v), by (hhnum);
egen nfaac93v  = mean(a93v), by (hhnum);
egen nfaoth    = mean(ao), by (hhnum); 
egen nfaac96o  = mean(a96o), by (hhnum); 
egen nfaac95o  = mean(a95o), by (hhnum);
egen nfaac94o  = mean(a94o), by (hhnum);
egen nfaac93o  = mean(a93o), by (hhnum);

drop a*;

sort hhnum;
qui by hhnum: keep if _n==1;

merge hhnum using corehh;
tab _merge;
drop if _merge==1; *incomplete questionnaire;
keep hhnum nfa* basspown;
sort hhnum;

merge hhnum using sec052b;
tab _merge;

mvencode nfa*, mv(0) ov;

gen nfaveh95=nfaveh-nfaac96v;
gen nfaveh94=nfaveh95-nfaac95v;
gen nfaveh93=nfaveh94-nfaac94v;
gen nfaveh92=nfaveh93-nfaac93v;
gen nfaoth95=nfaoth-nfaac96o;
gen nfaoth94=nfaoth95-nfaac95o;
gen nfaoth93=nfaoth94-nfaac94o;
gen nfaoth92=nfaoth93-nfaac93o;

**inventories
;
replace binvper1=100 if binvper1==0; *q answered incorrectly?;
replace binvper2=100 if binvper2==0; *q answered incorrectly?;
replace binvper3=100 if binvper3==0; *q answered incorrectly?;
replace binvper4=100 if binvper4==0; *q answered incorrectly?;
gen nfainv=binvetv1*(binvper1/100);
gen nfainv95=binvetv2*(binvper2/100);
gen nfainv94=binvetv3*(binvper3/100);
gen nfainv93=binvetv4*(binvper4/100);

mvencode nfainv*, mv(0) ov;

/*
**2nd method -- uses expenditure flow variables (found these to be quite
  unreliable and therefore decided to use 1st method -- also with first
  method can disaggregate by type of asset)
;
replace basspown=100 if basspown==0|basspown==.; *'0' - q answered incorrectly?;
replace bassvalu=bassvalu*(basspown/100);
egen a96=sum(bassvalu)  if bassacqy==96, by(hhnum);
egen a95=sum(bassvalu)  if bassacqy==95, by(hhnum);
egen a94=sum(bassvalu)  if bassacqy==94, by(hhnum);
egen a93=sum(bassvalu)  if bassacqy==93, by(hhnum);
egen abefore=sum(bassvalu) if bassacqy<93, by(hhnum);
egen nfaac96  = mean(a96), by (hhnum); *non-farm assets acquired in 1996;
egen nfaac95  = mean(a95), by (hhnum);
egen nfaac94  = mean(a94), by (hhnum);
egen nfaac93  = mean(a93), by (hhnum);
egen nfaacbef = mean(abefore), by (hhnum);
drop a*;

sort hhnum;
qui by hhnum: keep if _n==1;

egen nfa = rsum(nfaac96 nfaac95 nfaac94 nfaac93 nfaacbef);

merge hhnum using corehh;
tab _merge;
drop if _merge==1; *incomplete questionnaire;
keep hhnum nfa* basspown;
sort hhnum;

merge hhnum using sec052b;
tab _merge;

mvencode nfa* bequip* bequips*, mv(0) ov;

**note - I checked the data and basspown does not vary between assets
  for a particular household.  I had to make the assumption that basspown
  is applicable for the previous years.
;

gen netac96=(bequip1-bequips1)*(basspown/100);*net asset accumulation;
gen netac95=(bequip2-bequips2)*(basspown/100);
gen netac94=(bequip3-bequips3)*(basspown/100);
gen netac93=(bequip4-bequips4)*(basspown/100);
mvencode netac*, mv(0) ov;

gen netac96a=netac96;
gen netac95a=netac95;
gen netac94a=netac94;
gen netac93a=netac93;

gen nfasuss=0;
replace nfasuss=1 if netac96a>0&((nfaac96/netac96a<0.8)|(nfaac96/netac96a>1.2));
replace nfasuss=1 if netac95a>0&((nfaac95/netac95a<0.6)|(nfaac95/netac95a>1.4));
replace nfasuss=1 if netac94a>0&((nfaac94/netac94a<0.4)|(nfaac94/netac94a>1.6));
replace nfasuss=1 if netac93a>0&((nfaac93/netac93a<0.2)|(nfaac93/netac93a>1.8));
**identify those households with suspicious investment flows;

replace netac96a=nfaac96 if (nfaac96/netac96a>=0.8&nfaac96/netac96a<=1.2);
replace netac95a=nfaac95 if (nfaac95/netac95a>=0.6&nfaac95/netac95a<=1.4);
replace netac94a=nfaac94 if (nfaac94/netac94a>=0.4&nfaac94/netac94a<=1.6);
replace netac93a=nfaac93 if (nfaac93/netac93a>=0.2&nfaac93/netac93a<=1.8);
**the above allows for up to 20% p.a. depreciation/appreciation in the
  value of the assets
; 

gen nfa95=nfa-netac96a; 
gen nfa94=nfa95-netac95a; 
gen nfa93=nfa94-netac94a; 
gen nfa92=nfa93-netac93a; 

**fix data -- need to write note on this
;
replace nfa95=0 if nfa95<0;
replace nfa94=0 if nfa94<0;
replace nfa93=0 if nfa93<0;
replace nfa92=0 if nfa92<0;

**interpretation of nfa variables:
      nfa  - value of nfa at present
      nfa95 - value of nfa before capital transations of '96
      nfa94 - value of nfa before capital transations of '95 etc.
;
*/

label var nfaveh   "non-farm assets - vehicles";
label var nfaveh95 "non-farm assets - vehicles - 95";
label var nfaveh94 "non-farm assets - vehicles - 94";
label var nfaveh93 "non-farm assets - vehicles - 93";
label var nfaoth   "non-farm assets - other";
label var nfaoth95 "non-farm assets - other - 95";
label var nfaoth94 "non-farm assets - other - 94";
label var nfaoth93 "non-farm assets - other - 93";
label var nfainv   "val. inventory";
label var nfainv95 "val. inventory - 1yr ago";
label var nfainv94 "val. inventory - 2yrs ago";
label var nfainv93 "val. inventory - 3yrs ago";

keep hhnum nfa*;
sort hhnum;
save nfassets, replace;


log close;


