#delimit ;
capture log close;
log using do\nfdexp,replace;
****************************************************;
*                                                  *;
*    Name    : NFDEXP.DO                           *;
*    OBJECTIVE: Non-food expenditure               *;
****************************************************;
clear;
set more 1;

**first calculate monthly expenditures
;
use corehh;
keep hhnum hhsize;
des;

merge hhnum using sec111;
*tab _merge;
drop if _merge==2; *hhs 460125, 640126 -- incomplete questionnaires;
sort hhnum;
gen same=0;
replace same=1 if hhnum[_n+1]==hhnum[_n];
tab same;
keep if same==0;*3 duplicate obs dropped - check further into this;

**fix to the data -- reclassifying motransp as annual expenditure for some
  households
;
replace motransp=motransp/12 if hhnum==20608|hhnum==71019|hhnum==150513|
                                hhnum==210105|hhnum==210109|hhnum==460126|
                                hhnum==666602;

gen cigar=mcigare; 
gen enter=menterta; 
gen pers=mpersona; 
gen paper=mpapers; 
gen car=mcarcost; 
gen trans=motransp; 
gen wash=mwashpow; 
gen child=mchicare; 
gen dues=mdues;

*keep hhnum hhsize cigar enter pers paper car trans wash child dues;
sort hhnum;
drop _merge;
local temp1: tempfile;
save `temp1', replace;

***yearly expenditures***
;
use corehh;
keep hhnum hhsize;

merge hhnum using sec112;
*tab _merge;
drop if _merge==2; *hh 460125;
sort hhnum;
gen same=0;
replace same=1 if hhnum[_n+1]==hhnum[_n];
tab same;
keep if same==0;*3 duplicate obs dropped - check into this;

cap program drop temp1; *convert yearly to monthly expenditures;
program define temp1;

gen `1'= `2'/12;

end;
temp1 kitch ykithous; 
temp1 repair yrepair; 
temp1 linens ylinens; 
temp1 furn yfurapll; 
temp1 constr yconstru; 
temp1 shoes yshoes; 
temp1 cloths ycloths; 
temp1 mater yclothma; 
temp1 cerem ycerimo; 
temp1 holid yholiday; 
temp1 luxur yluxury;

*change to constr and repair variables suggested by Harold on 12/12/96 --
 done because repair was outlier
;
replace constr=repair if hhnum==20204;
replace repair=0 if hhnum==20204;

*keep hhnum hhsize kitch repair linens furn constr shoes cloths mater
      health cerem holid luxur; 
sort hhnum;
drop _merge;
local temp2: tempfile;
save `temp2', replace;

***health expenditures***
;
use corehh;
keep hhnum hhsize;

merge hhnum using sec112;
tab _merge;
drop if _merge==2; *hh 460125, 640126 - incomplete questionnaires;
sort hhnum;
gen same=0;
replace same=1 if hhnum[_n+1]==hhnum[_n];
tab same;
keep if same==0;*3 duplicate obs dropped - check into this;

gen health1 = yhealth/12;

keep hhnum hhsize health1;
sort hhnum;
 
merge hhnum using sec121;
tab _merge;
drop if _merge==2; *hh 220106;
drop _merge;

gen chroni = dismos*discost;
replace chroni = chroni*(12/dismos) if dismos>12; 
*above two lines give cost in last year;
replace chroni = chroni/12; *monthly cost;
replace chroni=0 if chroni==.;

egen chron = sum(chroni), by (hhnum);

sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum hhsize health1 chron;
sort hhnum;

merge hhnum using sec122;
tab _merge;
drop if _merge==2; *640126 - incomplete questionnaire;

egen acutei = rsum(ilconcos iltestco ilbaksco ildrugco);

egen acute = sum(acutei), by (hhnum);

sort hhnum;
qui by hhnum: keep if _n==1;

egen health2 = rsum(chron acute);

gen health = health1;
replace health=health2 if health2>health1;

keep hhnum hhsize health health1 health2;
sort hhnum;
local temp3: tempfile;
save `temp3', replace;

***remittances sent***
;
use sec072b;
gen remid = hhnum*100+perrec;
*sort remid;
*gen same=0;
*replace same=1 if remid[_n+1]==remid[_n];
*tab same;
*keep if same==0;*0 duplicate obs dropped;
egen remout = sum(rslsmos), by (hhnum);
replace remout=remout/6; *convert to monthly; 
sort hhnum;
qui by hhnum: keep if _n==1;

merge hhnum using corehh;
tab _merge;

keep hhnum hhsize remout;
sort hhnum;
local temp4: tempfile;
save `temp4', replace;

***rent and utilities***
;
use corehh;
keep hhnum bashki hhsize;

merge hhnum using sec091;
tab _merge;
drop if _merge==2; *hh 460125;
sort hhnum;
gen same=0;
replace same=1 if hhnum[_n+1]==hhnum[_n];
tab same;
keep if same==0;*3 duplicate obs dropped - check into this;

egen rent2 = rsum(rentpay rentkval);

gen elect=mxelect; 
gen gas=mxgas; 
gen coal=mxcoal; 
gen keros=mxkeros; 
gen wood=mxwood; 
gen oenerg=mxoenerg; 
gen waterx=mxwater; 
gen waste=mxwaste; 
gen trash=mxtrash;
gen condo=mdcondo; 
gen phone=teleppay; 

*keep hhnum bashki hhsize rent2 elect gas coal keros wood oenerg waterx waste
     trash condo phone; 
sort hhnum;
drop _merge;

**aggregate expenditures
;
merge hhnum using `temp1';
tab _merge;
drop _merge;
sort hhnum;

merge hhnum using `temp2';
tab _merge;
drop _merge;
sort hhnum;

merge hhnum using `temp3';
tab _merge;
list if _merge~=3;
drop _merge;
sort hhnum;

merge hhnum using `temp4';
tab _merge;
list if _merge~=3;
drop _merge;
sort hhnum;

egen othous = rsum(elect gas coal keros wood oenerg waterx waste
                   trash condo phone repair); *note -- leave constr out of
                                               expenditure for now;
egen educul = rsum(enter paper);
egen transpo = rsum(car trans);
egen cloth = rsum(shoes cloths mater);
replace remout=0 if remout==.;
egen other = rsum(cigar pers wash child dues
                  kitch linens furn cerem holid luxur);

*keep hhnum bashki hhsize 
     rent2 othous educul health health1 health2 transpo cloth remout 
     other constr;

sort hhnum;
save nfdexp, replace;

log close;




