#delimit ;
set trace off;
cap log close;
log using do\pexppred,replace;
***************************************************************;
*                                                             *;
*    Name     : PEXPPRED.DO                                   *;
*    OBJECTIVE: Analysis of changes in predicted expenditures *;
***************************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

use pexpdath;

cap program drop temp1;
program define temp1;
      local a `1';
      local b `2';
      local c `3';

      **predicted expenditure with 'current year' RHS variables;
      predict px`a'`c' if settlm==`c';

      **predicted expenditure with 'previous year' RHS variables;
      parse "$S_E_vl", parse(" ");
      local i 2;
      disp "I've started working on calculating pred exp. for 19`b'";
      while "``i''"!="" {;
            replace ``i''=``i''`b';
            disp "working on RHS variable --``i''--";
            local i = `i' + 1;
            };
      predict px`b'`c' if settlm==`c';
      gen cpex`a'`b'=(px`a'`c'/px`b'`c'-1)*100;

      keep hhnum settlm px`a'`c' px`b'`c' cpex`a'`b' $S_E_vl; *RHS var. at 19`b' values;
      sort hhnum;
      local temp1 : tempfile;
      save `temp1';

      use hhnum ychild* ochil* adult* elder* 
          using pexpdath;
      merge hhnum using `temp1'; *overlay 19`b' values with 1996 values;

      **demographic variables;
      disp "I'm working on the demographic variables";
      predict px`b'`c'd if settlm==`c';
      gen ddemog=abs(px`b'`c'd-px`b'`c');
      replace ychild=ychild`b'; *RHS var. at 19`b' values;
      replace ochilm=ochilm`b';
      replace ochilf=ochilf`b';
      replace adultm=adultm`b';
      replace adultf=adultf`b';
      replace elderm=elderm`b';
      replace elderf=elderf`b';
      *keep hhnum settlm px`a'`c' px`b'`c' $S_E_vl cpex`a'`b' ddemog;
      keep hhnum settlm px* $S_E_vl cpex`a'`b' ddemog;
      sort hhnum;
      local temp1 : tempfile;
      save `temp1', replace;

      use hhnum prim* middl* secon* high* 
          using pexpdath;
      merge hhnum using `temp1'; *overlay 19`b' values with 1996 values;

      **education variables;
      disp "Now, I'm working on the education variables, OK?";
      predict px`b'`c'e if settlm==`c';
      gen deducat=abs(px`b'`c'e-px`b'`c');
      replace primm=primm`b';
      replace primf=primf`b';
      replace middlm=middlm`b';
      replace middlf=middlf`b';
      replace seconm=seconm`b';
      replace seconf=seconf`b';
      replace highm=highm`b';
      replace highf=highf`b';
      *keep hhnum settlm px`a'`c' px`b'`c' $S_E_vl cpex`a'`b' d*;
      keep hhnum settlm px* $S_E_vl cpex`a'`b' d*;
      sort hhnum;
      local temp1 : tempfile;
      save `temp1', replace;

      **rest of the RHS variables;
      parse "$S_E_vl", parse(" ");
      local i 17;
      while "``i''"!="" {;
            local g = `i'-1;
            disp "working on RHS variable --``i''--: creating px`b'`c'`g'";
            
            use hhnum settlm ``i''* using pexpdath;
            merge hhnum using `temp1';
            
            predict px`b'`c'`g' if settlm==`c';
            gen d``i''=abs(px`b'`c'`g'-px`b'`c');

            replace ``i''=``i''`b'; *RHS var. at 19`b' values;
            *keep hhnum settlm px`a'`c' px`b'`c' $S_E_vl cpex`a'`b' d*;
            keep hhnum settlm px* $S_E_vl cpex`a'`b' d*;
            sort hhnum;
            save `temp1', replace;
            
            local i = `i' + 1;
            };
      *keep hhnum d*;
      save temp1, replace; 

      di _dup(65) "-";
      di "Percentage change in predicted expenditure between 19`b' and 19`a'";
      di _dup(65) "-";
      sum cpex`a'`b', det;
      di _dup(65) "-"; di _dup(65) " "; di _dup(65) " ";

      egen totch=rsum(d*);
      replace ddemog=ddemog/totch*100;
      replace deducat=deducat/totch*100;
      local i 17;
      while `i'<=`g'+1 {;
            disp "working on variable --d``i''--";
            replace d``i''=d``i''/totch*100;
            local i = `i' + 1;
            };    
      save temp1, replace; 
            
      di _dup(65) "-";
      di "Percentage contribution of each variable to change in predicted expenditure between 19`b' and 19`a'";
      di "(households with change in predicted expenditure between 19`b' and 19`a')";
      di _dup(65) "-";
      sum d* if cpex`a'`b'~=0;
      di _dup(65) "-"; di _dup(65) " "; di _dup(65) " ";

end;

*fit   tothhx1
      ychild ochilm ochilf adultm adultf elderm elderf
      primm primf middlm middlf seconm seconf highm highf
      absent 
      pensy
      nfaveh nfaoth nfainv
      orc_ov pas_ov cro_ov
      fa_mac
      animlv animmv animsv
      emp_n /*empshare*/
      if settlm==0;
*temp1 96 95 0;

*use pexpdath, clear;
fit   tothhx1
      ychild ochilm ochilf adultm adultf elderm elderf
      primm primf middlm middlf seconm seconf highm highf
      absent 
      pensy
      nfaveh nfaoth nfainv
      landov
      fa_mac
      animv
      emp_n /*empshare*/
      if settlm==1;
temp1 96 95 1;

/*      
predict pexp_1 if settlm==1;

gen predex=pexp_0;
replace predex=pexp_1 if settlm==1;
drop pexp_0 pexp_1;

corr predex tothhx1;

keep hhnum tothhx1 predex;
sort hhnum;
*save predexp, replace;
*/


log close;


