#delimit ;
cap log close;
log using do\reg95r,replace;
********************************************************;
*                                                      *;
*    Name     : REG95R.DO                              *;
*    OBJECTIVE: Receipt of NE regressions - rural 95   *;
*                                                      *;
********************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;

***RURAL 1995: REGRESSIONS USING 'FULL' EXPENDITURE (BASE MODEL)***;
use nereg;

***VERSION 1***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem

        if settlm==0,
        absorb(bashki);

***VERSION 2***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95

        if settlm==0,
        absorb(bashki);

***VERSION 3***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95 /*exp1_NE*/

        if settlm==0,
        absorb(bashki);

***VERSION 4***;
regress NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95 /*exp1_NE*/
        NE_pf95

        if settlm==0;

***VERSION 1A (net entitlement included)***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        en2upl95

        if settlm==0,
        absorb(bashki);

***VERSION 2A (net entitlement included)***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95
        en2upl95

        if settlm==0,
        absorb(bashki);

***VERSION 3A (net entitlement included)***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95 /*exp1_NE*/
        en2upl95

        if settlm==0,
        absorb(bashki);

***VERSION 4A (net entitlement included)***;
regress NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95 /*exp1_NE*/
        NE_pf95
        en2upl95

        if settlm==0;


use nereg, clear;
***RURAL 1995: REGRESSIONS USING EXPENDITURE LESS DURABLE FLOW***;

***VERSION 1***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem

        if settlm==0,
        absorb(bashki);

***VERSION 2***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp2r95

        if settlm==0,
        absorb(bashki);

***VERSION 3***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp2r95 /*exp2_NE*/

        if settlm==0,
        absorb(bashki);

***VERSION 4***;
regress NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp2r95 /*exp2_NE*/
        NE_pf95

        if settlm==0;

***VERSION 1A (net entitlement included)***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        en2upl95

        if settlm==0,
        absorb(bashki);

***VERSION 2A (net entitlement included)***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp2r95
        en2upl95

        if settlm==0,
        absorb(bashki);

***VERSION 3A (net entitlement included)***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp2r95 /*exp2_NE*/
        en2upl95

        if settlm==0,
        absorb(bashki);

***VERSION 4A (net entitlement included)***;
regress NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp2r95 /*exp2_NE*/
        NE_pf95
        en2upl95

        if settlm==0;

use nereg, clear;
***RURAL 1995: REGRESSIONS USING EXPENDITURE LESS DURABLE FLOW AND IMPUTED RENT***;

***VERSION 1***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem

        if settlm==0,
        absorb(bashki);

***VERSION 2***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp3r95

        if settlm==0,
        absorb(bashki);

***VERSION 3***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp3r95 /*exp3_NE*/

        if settlm==0,
        absorb(bashki);

***VERSION 4***;
regress NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp3r95 /*exp3_NE*/
        NE_pf95

        if settlm==0;

***VERSION 1A (net entitlement included)***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        en2upl95

        if settlm==0,
        absorb(bashki);

***VERSION 2A (net entitlement included)***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp3r95
        en2upl95

        if settlm==0,
        absorb(bashki);

***VERSION 3A (net entitlement included)***;
areg    NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp3r95 /*exp3_NE*/
        en2upl95

        if settlm==0,
        absorb(bashki);

***VERSION 4A (net entitlement included)***;
regress NE95
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp3r95 /*exp3_NE*/
        NE_pf95
        en2upl95

        if settlm==0;

log close;
