#delimit ;
cap log close;
log using do\reghet95,replace;
************************************************;
*                                              *;
*    Name     : REGHET95.DO                    *;
*    OBJECTIVE: Test of heteroskedasticity     *;
*                                              *;
************************************************;
clear;
set more 1;
set log linesize 160;
set display linesize 160;
set matsize 150;

***Lagrange Multiplier test;
***RURAL 1995: REGRESSIONS USING 'FULL' EXPENDITURE (BASE MODEL)***;
use nereg, clear;

***VERSION 4***;
fit NE
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95
        NE_pf95

        if settlm==0;

predict res if settlm==0, residuals;
predict NEpred if settlm==0;

gen v=res^2;

sca sighat = _result(9);
sca sighat2 = sighat^2;
sca list sighat;

gen vtrans = v/sighat2-1;
sum vtrans, det;

*list hhnum vtrans res NE NEpred if vtrans>20 & vtrans~=.;
*list if vtrans>20 & vtrans~=.;

sktest res;

**1st Z;
regress vtrans
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95
        NE_pf95

        if settlm==0;

sca LM=_result(2)/2;
mat V = get(VCE);
sca q = colsof(V)-1;
sca pval=chiprob(q,LM);
di in gr "Chi-sq(" q ") = " in ye %8.2f LM;
di in gr "Prob > Chi-sq = " in ye %8.3f pval;

**2nd Z;
qui tab bashki, gen(badum);
regress vtrans badum*

        if settlm==0;

sca LM=_result(2)/2;
mat V = get(VCE);
sca q = colsof(V)-1;
sca pval=chiprob(q,LM);
di in gr "Chi-sq(" q ") = " in ye %8.2f LM;
di in gr "Prob > Chi-sq = " in ye %8.3f pval;

**combined Z;
regress    vtrans
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95 badum*

        if settlm==0;

sca LM=_result(2)/2;
mat V = get(VCE);
sca q = colsof(V)-1;
sca pval=chiprob(q,LM);
di in gr "Chi-sq(" q ") = " in ye %8.2f LM;
di in gr "Prob > Chi-sq = " in ye %8.3f pval;


***F-test;
***RURAL 1996: REGRESSIONS USING 'FULL' EXPENDITURE (BASE MODEL)***;
use nereg, clear;

***VERSION 4***;
fit NE
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95
        NE_pf95

        if settlm==0;

predict res if settlm==0, residuals;

gen v=res^2;

sca sighat = _result(9);
sca sighat2 = sighat^2;

gen vtrans = v - sighat2;
sum vtrans, det;

*list hhnum vtrans res if vtrans>7000000 & vtrans~=.;

sktest res;

**1st Z;
regress vtrans
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95
        NE_pf95

        if settlm==0;

**2nd Z;
qui tab bashki, gen(badum);
regress vtrans badum*

        if settlm==0;

**combined Z;
regress    vtrans
        ychild95 ochilm95 ochilf95 adultm95 adultf95 elderm95 elderf95
        penoa95 penot95
        orc_ov95 pas_ov95 cro_ov95
        animlv95 animmv95 animsv95
        empwag95
        commutem
        pexp1r95 badum*

        if settlm==0;
               
log close;
