#delimit;
capture log close;
log using do/rentimp,replace;
****************************************************************;
*                                                              *;
*    Name    : RENTIMP.DO                                      *;
*    OBJECTIVE: Hedonic rent regressions and creation of       *;
*               imputed rent variable                          *;
****************************************************************;
clear;
set more 1;
set log linesize 132;
set display linesize 132;

use corehh;
keep hhnum bashki region;
sort hhnum;

merge hhnum using new;
drop _merge;
sort hhnum;

merge hhnum using sec091;
tab _merge;
drop if _merge==2; *hhs 460125, 640126 -- incomplete questionnaires;
sort hhnum;
gen same=0;
replace same=1 if hhnum[_n+1]==hhnum[_n];
tab same;
keep if same==0;*3 duplicate obs dropped - check further into this;
*keep hhnum bashki region rentvalu rentpay rentkval hhtype rooms renting 
     walls toiletty toiletlo water waterloc energy telephon;

gen locat=0;
replace locat=1 if bashki>60; *urban/rural;

label define locat
1 "urban"
0 "rural"
;
label value locat locat;
label var locat "urban/rural location";

**look at rentvalu and dwevalue
;

replace rentvalu=. if rentvalu==0; *get rid of zero rents;
list hhnum bashki hhtype rooms dwevalue rentvalu renting
     if renting==1 & rentvalu==. & new==1, nodisp;

replace dwevalue=. if dwevalue==0; *get rid of zero dwelling value;
list hhnum bashki hhtype rooms dwevalue rentvalu renting
     if renting==1 & dwevalue==. & new==1, nodisp;

sum rentvalu, det;
sum dwevalue, det; 

egen mean1=mean(rentvalu);
egen sd1=sd(rentvalu);

gen upper1=mean1+sd1*3;
gen upper2=mean1*5;
gen outlier1=1 if (rentvalu>upper1 & rentvalu~=.) & 
                 (rentvalu>upper2 & rentvalu~=.);
drop mean1 sd1 upper1 upper2;
list hhnum bashki hhtype rooms dwevalue rentvalu 
     if outlier1==1 & new==1, nodisp;

egen mean1=mean(dwevalue);
egen sd1=sd(dwevalue);

gen upper1=mean1+sd1*3;
gen upper2=mean1*5;
gen outlier2=1 if (dwevalue>upper1 & dwevalue~=.) & 
                  (dwevalue>upper2 & dwevalue~=.);
drop mean1 sd1 upper1 upper2;
list hhnum bashki hhtype rooms dwevalue rentvalu
     if hhnum==30212, nodisp;
list hhnum bashki hhtype rooms dwevalue rentvalu
     if new==1 & ((outlier2==1&locat==0)|(outlier2==1&locat==1&rooms<=3)), nodisp;

gen lnrent=log(rentvalu);

gen subjror=((rentvalu*12)/dwevalue)*100;

sum subjror, det;

list hhnum bashki hhtype rooms dwevalue rentvalu walls toiletty water
     if subjror<0.9 & new==1, nodisp;
list hhnum bashki hhtype rooms dwevalue rentvalu walls toiletty water
     if subjror>240 & subjror~=. & new==1, nodisp;

***create variables for hedonic regression
;
gen hhtype1=0; gen hhtype2=0; gen hhtype3=0;
replace hhtype1=1 if hhtype==1;
replace hhtype2=1 if hhtype==2;
replace hhtype3=1 if hhtype==3;

gen walls1=0; gen walls2=0; gen walls3=0;
replace walls1=1 if walls==3;
replace walls2=1 if walls==5;
replace walls3=1 if walls==1|walls==2|walls==4|walls==6;

gen toilet1=0; gen toilet2=0; gen toilet3=0;
gen toilet4=0; gen toilet5=0; gen toilet6=0;
gen toilet7=0;
replace toilet1=1 if toiletty==1&toiletlo==1;           *flush, in dwell;
replace toilet2=1 if toiletty==1&toiletlo==2;           *flush, in build;
replace toilet3=1 if toiletty==1&toiletlo==3;           *flush, out build;
replace toilet4=1 if toiletty==2&toiletlo==1;           *latrine, in dwell;
replace toilet5=1 if toiletty==2&toiletlo==2;           *latrine, in build;
replace toilet6=1 if toiletty==2&toiletlo==3;           *latrine, out build;
replace toilet7=1 if toilet1==0&toilet2==0&toilet3==0&
                     toilet4==0&toilet5==0&toilet6==0;  *other; 

gen water1=0; gen water2=0; gen water3=0; 
gen water4=0; gen water5=0; gen water6=0;
gen water7=0; gen water8=0;
replace water1=1 if water==1&waterloc==1;           *piped, in dwell;
replace water2=1 if water==1&waterloc==2;           *piped, in build;
replace water3=1 if water==1&waterloc==3;           *piped, out build;
replace water4=1 if water==2&waterloc==1;           *own system, in dwell;
replace water5=1 if water==2&waterloc==2;           *own system, in build;
replace water6=1 if water==2&waterloc==3;           *own system, out build;
replace water7=1 if water==3;                       *river;
replace water8=1 if water1==0|water2==0|water3==0|
                    water4==0|water5==0|water6==0|
                    water7==0;                      *other;

gen energy1=0; gen energy2=0; gen energy3=0; gen energy4=0;
replace energy1=1 if energy==1;
replace energy2=1 if energy==2;
replace energy3=1 if energy==3;
replace energy4=1 if energy==4|energy==5;

gen elect=0;
replace elect=1 if electhrs>0 & electhrs~=.;

gen hh1_loc=hhtype1*locat;
gen hh2_loc=hhtype2*locat;
gen room_loc=rooms*locat;

label var hhtype1 "dvar-apartment"; 
label var hhtype2 "dvar-multi.fam.unit"; 
label var hhtype3 "dvar-house";
label var hh1_loc "hhtype1*locat";
label var hh2_loc "hhtype2*locat";
label var room_loc "rooms*locat";
label var walls1 "dvar-stone"; 
label var walls2 "dvar-mud"; 
label var walls3 "dvar-other"; 
label var toilet1 "dvar-flush,indwell"; 
label var toilet2 "dvar-flush,inbuild"; 
label var toilet3 "dvar-flush,outbuild"; 
label var toilet4 "dvar-latrine,indwell"; 
label var toilet5 "dvar-latrine,inbuild"; 
label var toilet6 "dvar-latrine,outbuild"; 
label var toilet7 "dvar-other"; 
label var water1 "dvar-piped,indwell"; 
label var water2 "dvar-piped,inbuild"; 
label var water3 "dvar-piped,outbuild"; 
label var water4 "dvar-ownsys,indwell"; 
label var water5 "dvar-ownsys,inbuild"; 
label var water6 "dvar-ownsys,outbuild"; 
label var water7 "dvar-river"; 
label var water8 "dvar-other"; 
label var energy1 "dvar-electricity"; 
label var energy2 "dvar-wood"; 
label var energy3 "dvar-kerosene"; 
label var energy4 "dvar-other";
label var elect "electricity avail during last week"; 

save tempdat1, replace;

use tempdat1;

replace rentvalu=. if outlier1==1;
replace dwevalue=. if outlier2==1;

gen dwev2=dwevalue*0.09/12; *this is the opportunity cost of investment in
                             dwelling.  9% interest rate is the median of 
                             estimated ROR on investment;
gen lndwev2=log(dwev2);

*des;
*sum;

regress rentval locat
                hhtype1 hhtype2
                rooms
                room_loc
                walls2 walls3
                toilet1 toilet2 toilet3 toilet4 toilet5 toilet7
                water2 water3 water4 water5 water6 water7 water8
                energy1 energy3 energy4
                telephon
                elect
                studio
                ; 

predict imprent;
replace imprent=200 if imprent<200; *Harold decided to set these to the value
                                     of the 5th percentile for rentval;

regress dwev2    locat
                 hhtype1 hhtype2
                 rooms
                 room_loc
                 walls2 walls3
                 toilet1 toilet2 toilet3 toilet4 toilet5 toilet7
                 water2 water3 water4 water5 water6 water7 water8
                 energy1 energy3 energy4
                 telephon
                 elect
                 studio
                 ; 
predict dwevhat;

corr rentval dwev2;
corr imprent dwevhat;

keep hhnum 
     rentvalu lnrent dwev2 lndwev2
     imprent dwevhat
     locat
     hhtype1 hhtype2 hhtype3
     rooms
     room_loc
     walls1 walls2 walls3
     toilet1 toilet2 toilet3 toilet4 toilet5 toilet6 toilet7
     water1 water2 water3 water4 water5 water6 water7 water8
     energy1 energy2 energy3 energy4
     telephon
     elect
     studio
;
sort hhnum;
save rentimp, replace;

log close;
