#delimit ;
cap log close;
log using do\socassan,replace;

*************************************************************;
*                                                           *;
*    Name     : SOCASSAN.DO                                 *;
*    OBJECTIVE: Analyse social assistance data (Sec 8.1)    *;
*                                                           *;
*************************************************************;
clear;
set more 1;
set log linesize 132;
set display linesize 132;
/*
**create social assistance data set
;
use hhnum settlm using corehh;

merge hhnum using sec081;
tab _merge;
drop if _merge==2; *hhs 220106, 640126 - incomplete questionnaires;

gen a =(saany==1&sacode==1);
gen b =(saany==1&sacode==2);
gen c =(saany==1&sacode==5);
gen d =(saany==1&sacode==6);
gen e =(saany==1&sacode==7);

egen penany = sum(a), by(hhnum);
egen dispany= sum(b), by(hhnum);
egen ubany  = sum(c), by(hhnum);
egen NEany  = sum(d), by(hhnum);
egen disaany= sum(e), by(hhnum);
drop a b c d e;

gen a =sapay if sacode==1;
gen b =sapay if sacode==2;
gen c =sapay if sacode==5;
gen d =sapay if sacode==6;
gen e =sapay if sacode==7;

egen penamt =sum(a), by(hhnum);
egen dispamt=sum(b), by(hhnum);
egen ubamt  =sum(c), by(hhnum);
egen NEamt  =sum(d), by(hhnum);
egen disaamt=sum(e), by(hhnum);
drop a b c d e;

sort hhnum;
qui by hhnum: keep if _n==1;

mvencode penamt dispamt ubamt NEamt disaamt, mv(0) ov;

keep hhnum settlm pen* dis* ub* NE*;

merge hhnum using sec082;
tab _merge;
drop if _merge==2; *hhs 220106, 640126 - incomplete questionnaires;

gen a =(sbapply==1&sbcode==1);
gen b =(sbapply==1&sbcode==2);
gen c =(sbapply==1&sbcode==5);
gen d =(sbapply==1&sbcode==6);
gen e =(sbapply==1&sbcode==7);

egen penapp = sum(a), by(hhnum);
egen dispapp= sum(b), by(hhnum);
egen ubapp  = sum(c), by(hhnum);
egen NEapp  = sum(d), by(hhnum);
egen disaapp= sum(e), by(hhnum);
drop a b c d e;

gen a =sbapyear if sbcode==1;
gen b =sbapyear if sbcode==2;
gen c =sbapyear if sbcode==5;
gen d =sbapyear if sbcode==6;
gen e =sbapyear if sbcode==7;

egen penyr = mean(a), by(hhnum);
egen dispyr= mean(b), by(hhnum);
egen ubyr  = mean(c), by(hhnum);
egen NEyr  = mean(d), by(hhnum);
egen disayr= mean(e), by(hhnum);
drop a b c d e;

gen a =sbapreas if sbcode==1;
gen b =sbapreas if sbcode==2;
gen c =sbapreas if sbcode==5;
gen d =sbapreas if sbcode==6;
gen e =sbapreas if sbcode==7;

egen penrea = mean(a), by(hhnum);
egen disprea= mean(b), by(hhnum);
egen ubrea  = mean(c), by(hhnum);
egen NErea  = mean(d), by(hhnum);
egen disarea= mean(e), by(hhnum);
drop a b c d e;

sort hhnum;
qui by hhnum: keep if _n==1;

label define reas
1 "not eligible"
2 "no funds"
3 "waiting"
4 "injustice"
;
label value penrea reas;
label value disprea reas;
label value ubrea reas;
label value NErea reas;
label value disarea reas;

keep hhnum settlm pen* dis* ub* NE*;

save sadat, replace;
*/

**analyse social assistance data - 1
;
/*
use sadat;

list hhnum NEamt penamt  if NEany==1&penany==1;
list hhnum NEamt ubamt   if NEany==1&ubany==1;
list hhnum NEamt dispamt if NEany==1&dispany==1;
list hhnum NEamt disaamt if NEany==1&disaany==1;

tab dispany disaany;

sum penapp  if penany==0;
sum dispapp if dispany==0;
sum ubapp   if ubany==0;
sum NEapp   if NEany==0;
sum disaapp if disaany==0;

tab penrea  if penany==0;
tab disprea if dispany==0;
tab ubrea   if ubany==0;
tab NErea   if NEany==0;
tab disarea if disaany==0;
*/

**check correspondence b/w receipt of disability benefit and sickness
;

use sadat;
keep hhnum dispany disaany;
gen disany=(dispany==1|disaany==1);

merge hhnum using sec031;
keep if _merge==3;

gen inv=(notlook==2|notlook==3);
egen numinv=sum(inv), by(hhnum);

sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum dispany disaany disany numinv;

sum;
*tab numinv if disaany==1;
*tab numinv if dispany==1;

tab numinv if disany==1;
tab numinv disany;

use sec121, clear;
gen chron=1;

sort hhnum;
egen numchron=sum(chron), by(hhnum);
sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum numchron;
sort hhnum;
save tempdat1, replace;

use sec122;
gen accu=1;

sort hhnum;
egen numaccu=sum(accu), by(hhnum);
sort hhnum;
qui by hhnum: keep if _n==1;

keep hhnum numaccu;
sort hhnum;
save tempdat2, replace;

use sadat;
keep hhnum dispany disaany;
gen disany=(dispany==1|disaany==1);

merge hhnum using tempdat1;
tab _merge;
drop if _merge==2;
drop _merge;
sort hhnum;

merge hhnum using tempdat2;
tab _merge;
*keep if _merge==1|_merge==3;

replace numchron=0 if numchron==.;
replace numaccu=0 if numaccu==.;
gen numill=numchron+numaccu;

keep hhnum dispany disaany disany numill;
sum;

*tab numill if dispany==1;
*tab numill if disaany==1;

tab numill if disany==1;
tab numill disany;

/*
**analyse social assistance data - 2
;
cap program drop socmac;
program define socmac;

clear;
use if sacode==`1' using sec081;
local temp: tempfile;
save `temp', replace;

use corehh;
keep hhnum genhh agehh bashki;

merge hhnum using `temp';
*tab _merge;
drop if _merge==2; *hhs 220106, 640126 -- incomplete questionnaires;
mvencode saany sa95any sa94any sa93any, mv(0) ov;
gen sa96_y=0;
replace sa96_y=1 if saany==1 & sa95any==0;
gen sa95_y=0;
replace sa95_y=1 if sa95any==1 & sa94any==0;
gen sa94_y=0;
replace sa94_y=1 if sa94any==1 & sa93any==0;

gen sa96_n=0;
replace sa96_n=1 if saany==0 & sa95any==1;
gen sa95_n=0;
replace sa95_n=1 if sa95any==0 & sa94any==1;
gen sa94_n=0;
replace sa94_n=1 if sa94any==0 & sa93any==1;

gen sa96_95r=sapay/sa95pay if sapay>0 & sa95pay>0; 
gen sa95_94r=sa95pay/sa94pay if sa95pay>0 & sa94pay>0;
gen sa94_93r=sa94pay/sa93pay if sa94pay>0 & sa93pay>0;

egen sasum = rsum(saany sa95any sa94any sa93any);

di _dup(65) "-";
di "Table 1: Proportion of households receiving -`2'- in each year";
di "Alabania 1996 (unweighted), table produced: $S_DATE";
di _dup(65) "-";
sum saany sa95any sa94any sa93any;
di _dup(65) "-"; di _dup(65) " "; di _dup(65) " ";

tab sasum if saany==1;
tab sasum if saany==0;

di _dup(65) "-";
di "Table 2: Proportion of households that received -`2'- year n, but not in year n-1";
di "Alabania 1996 (unweighted), table produced: $S_DATE";
di _dup(65) "-";
sum sa96_y sa95_y sa94_y;
di _dup(65) "-"; di _dup(65) " "; di _dup(65) " ";

di _dup(65) "-";
di "Table 3: Proportion of households that received -`2'- year n-1, but not in year n";
di "Alabania 1996 (unweighted), table produced: $S_DATE";
di _dup(65) "-";
sum sa96_n sa95_n sa94_n;
di _dup(65) "-"; di _dup(65) " "; di _dup(65) " ";

di _dup(65) "-";
di "Table 4: Year-on-year ratios of -`2'- monthly payments (those hholds with positive payments in both years";
di "Alabania 1996 (unweighted), table produced: $S_DATE";
di _dup(65) "-";
sum sa96_95r sa95_94r sa94_93r, detail;
di _dup(65) "-"; di _dup(65) " "; di _dup(65) " ";

di _dup(65) "-";
di "List of households with 'outliers' in year-on-year ratios of monthly payments for -`2'-";
di _dup(65) "-";
list    hhnum bashki sapay sa95pay sa94pay sa93pay sa96_95r sa95_94r sa94_93r
        if sa96_95r<0.2|(sa96_95r>2&sa96_95r~=.)|
           sa95_94r<0.2|(sa95_94r>2&sa95_94r~=.)|
           sa94_93r<0.2|(sa94_93r>2&sa94_93r~=.), nodisplay;
di _dup(65) "-"; di _dup(65) " "; di _dup(65) " ";

end;

socmac 6 "monthly social assistance";
socmac 1 "old age pension";
socmac 5 "unemployment benefits";
socmac 3 "disability pension";
socmac 7 "disability allowance";

/*
socmac 2 "survivor pension";
socmac 4 "other insurance benefits";
socmac 8 "caretaker allowance";
socmac 9 "other soc. welfare";
socmac 10 "grant from NGOs etc";
socmac 11 "in-kind from NGOs etc";
*/
*/

log close;
